@@ -29,7 +29,7 @@ LOG = logging.getLogger(__name__)
 
 KEEPALIVED_STATE_CHANGE_SERVER_BACKLOG = 4096
 
-TRANSLATION_MAP = {'master': constants.HA_ROUTER_STATE_ACTIVE,
+TRANSLATION_MAP = {'primary': constants.HA_ROUTER_STATE_ACTIVE,
                    'backup': constants.HA_ROUTER_STATE_STANDBY,
                    'fault': constants.HA_ROUTER_STATE_STANDBY,
                    'unknown': constants.HA_ROUTER_STATE_UNKNOWN}
@@ -129,28 +129,28 @@ class AgentMixin(object):
 
         This function will also update the metadata proxy, the radvd daemon,
         process the prefix delegation and inform to the L3 extensions. If the
-        HA router changes to "master", this transition will be delayed for at
-        least "ha_vrrp_advert_int" seconds. When the "master" router
+        HA router changes to "primary", this transition will be delayed for at
+        least "ha_vrrp_advert_int" seconds. When the "primary" router
         transitions to "backup", "keepalived" will set the rest of HA routers
-        to "master" until it decides which one should be the only "master".
-        The transition from "backup" to "master" and then to "backup" again,
+        to "primary" until it decides which one should be the only "primary".
+        The transition from "backup" to "primary" and then to "backup" again,
         should not be registered in the Neutron server.
 
         :param router_id: router ID
-        :param state: ['master', 'backup']
+        :param state: ['primary', 'backup']
         """
         if not self._update_transition_state(router_id, state):
             eventlet.spawn_n(self._enqueue_state_change, router_id, state)
             eventlet.sleep(0)
 
     def _enqueue_state_change(self, router_id, state):
-        # NOTE(ralonsoh): move 'master' and 'backup' constants to n-lib
-        if state == 'master':
+        # NOTE(ralonsoh): move 'primary' and 'backup' constants to n-lib
+        if state == 'primary':
             eventlet.sleep(self.conf.ha_vrrp_advert_int)
         if self._update_transition_state(router_id) != state:
             # If the current "transition state" is not the initial "state" sent
             # to update the router, that means the actual router state is the
-            # same as the "transition state" (e.g.: backup-->master-->backup).
+            # same as the "transition state" (e.g.: backup-->primary-->backup).
             return
 
         ri = self._get_router_info(router_id)
@@ -163,6 +163,15 @@ class AgentMixin(object):
                  'agent %(host)s',
                  state_change_data)
 
+        # Set external gateway port link up or down according to state
+        if state == 'primary':
+            ri.set_external_gw_port_link_status(link_up=True, set_gw=True)
+        elif state == 'backup':
+            ri.set_external_gw_port_link_status(link_up=False)
+        else:
+            LOG.warning('Router %s has status %s, '
+                        'no action to router gateway device.',
+                        router_id, state)
         # TODO(dalvarez): Fix bug 1677279 by moving the IPv6 parameters
         # configuration to keepalived-state-change in order to remove the
         # dependency that currently exists on l3-agent running for the IPv6
@@ -172,7 +181,7 @@ class AgentMixin(object):
         if self.conf.enable_metadata_proxy:
             self._update_metadata_proxy(ri, router_id, state)
         self._update_radvd_daemon(ri, state)
-        self.pd.process_ha_state(router_id, state == 'master')
+        self.pd.process_ha_state(router_id, state == 'primary')
         self.state_change_notifier.queue_event((router_id, state))
         self.l3_ext_manager.ha_state_change(self.context, state_change_data)
 
@@ -180,7 +189,7 @@ class AgentMixin(object):
         if not self.use_ipv6:
             return
 
-        ipv6_forwarding_enable = state == 'master'
+        ipv6_forwarding_enable = state == 'primary'
         if ri.router.get('distributed', False):
             namespace = ri.ha_namespace
         else:
@@ -193,7 +202,7 @@ class AgentMixin(object):
         # If ipv6 is enabled on the platform, ipv6_gateway config flag is
         # not set and external_network associated to the router does not
         # include any IPv6 subnet, enable the gateway interface to accept
-        # Router Advts from upstream router for default route on master
+        # Router Advts from upstream router for default route on primary
         # instances as well as ipv6 forwarding. Otherwise, disable them.
         ex_gw_port_id = ri.ex_gw_port and ri.ex_gw_port['id']
         if ex_gw_port_id:
@@ -206,7 +215,7 @@ class AgentMixin(object):
         # NOTE(slaweq): Since the metadata proxy is spawned in the qrouter
         # namespace and not in the snat namespace, even standby DVR-HA
         # routers needs to serve metadata requests to local ports.
-        if state == 'master' or ri.router.get('distributed', False):
+        if state == 'primary' or ri.router.get('distributed', False):
             LOG.debug('Spawning metadata proxy for router %s', router_id)
             self.metadata_driver.spawn_monitored_metadata_proxy(
                 self.process_monitor, ri.ns_name, self.conf.metadata_port,
@@ -217,9 +226,9 @@ class AgentMixin(object):
                 self.process_monitor, ri.router_id, self.conf, ri.ns_name)
 
     def _update_radvd_daemon(self, ri, state):
-        # Radvd has to be spawned only on the Master HA Router. If there are
+        # Radvd has to be spawned only on the primary HA Router. If there are
         # any state transitions, we enable/disable radvd accordingly.
-        if state == 'master':
+        if state == 'primary':
             ri.enable_radvd()
         else:
             ri.disable_radvd()
