@@ -55,7 +55,7 @@ class HaRouterNamespace(namespaces.RouterNamespace):
     It does so to prevent sending gratuitous ARPs for interfaces that got VIP
     removed in the middle of processing.
     It also disables ipv6 forwarding by default. Forwarding will be
-    enabled during router configuration processing only for the master node.
+    enabled during router configuration processing only for the primary node.
     It has to be disabled on all other nodes to avoid sending MLD packets
     which cause lost connectivity to Floating IPs.
     """
@@ -66,11 +66,12 @@ class HaRouterNamespace(namespaces.RouterNamespace):
 
 
 class HaRouter(router.RouterInfo):
-    def __init__(self, *args, **kwargs):
+    def __init__(self, state_change_callback, *args, **kwargs):
         super(HaRouter, self).__init__(*args, **kwargs)
 
         self.ha_port = None
         self.keepalived_manager = None
+        self.state_change_callback = state_change_callback
         self._ha_state = None
         self._ha_state_path = None
 
@@ -95,12 +96,12 @@ class HaRouter(router.RouterInfo):
         return self.router.get('ha_vr_id')
 
     def _check_and_set_real_state(self):
-        # When the physical host was down/up, the 'master' router may still
+        # When the physical host was down/up, the 'primary' router may still
         # have its original state in the _ha_state_path file. We directly
         # reset it to 'backup'.
         if (not self.keepalived_manager.check_processes() and
                 os.path.exists(self.ha_state_path) and
-                self.ha_state == 'master'):
+                self.ha_state == 'primary'):
             self.ha_state = 'backup'
 
     @property
@@ -109,7 +110,12 @@ class HaRouter(router.RouterInfo):
             return self._ha_state
         try:
             with open(self.ha_state_path, 'r') as f:
-                self._ha_state = f.read()
+                # TODO(haleyb): put old code back after a couple releases,
+                # Y perhaps, just for backwards-compat
+                # self._ha_state = f.read()
+                ha_state = f.read()
+                ha_state = 'primary' if ha_state == 'master' else ha_state
+                self._ha_state = ha_state
         except (OSError, IOError):
             LOG.debug('Error while reading HA state for %s', self.router_id)
         return self._ha_state or 'unknown'
@@ -128,7 +134,7 @@ class HaRouter(router.RouterInfo):
     def ha_namespace(self):
         return self.ns_name
 
-    def is_router_master(self):
+    def is_router_primary(self):
         """this method is normally called before the ha_router object is fully
         initialized
         """
@@ -150,6 +156,7 @@ class HaRouter(router.RouterInfo):
         self._init_keepalived_manager(process_monitor)
         self._check_and_set_real_state()
         self.ha_network_added()
+        self.update_initial_state(self.state_change_callback)
         self.spawn_state_change_monitor(process_monitor)
 
     def _init_keepalived_manager(self, process_monitor):
@@ -299,14 +306,14 @@ class HaRouter(router.RouterInfo):
             onlink_route_cidr in onlink_route_cidrs]
 
     def _should_delete_ipv6_lladdr(self, ipv6_lladdr):
-        """Only the master should have any IP addresses configured.
+        """Only the primary should have any IP addresses configured.
         Let keepalived manage IPv6 link local addresses, the same way we let
-        it manage IPv4 addresses. If the router is not in the master state,
+        it manage IPv4 addresses. If the router is not in the primary state,
         we must delete the address first as it is autoconfigured by the kernel.
         """
         manager = self.keepalived_manager
         if manager.get_process().active:
-            if self.ha_state != 'master':
+            if self.ha_state != 'primary':
                 conf = manager.get_conf_on_disk()
                 managed_by_keepalived = conf and ipv6_lladdr in conf
                 if managed_by_keepalived:
@@ -315,23 +322,21 @@ class HaRouter(router.RouterInfo):
                 return False
         return True
 
-    def _disable_ipv6_addressing_on_interface(self, interface_name,
-                                              namespace=None):
+    def _disable_ipv6_addressing_on_interface(self, interface_name):
         """Disable IPv6 link local addressing on the device and add it as
         a VIP to keepalived. This means that the IPv6 link local address
-        will only be present on the master.
+        will only be present on the primary.
         """
-        namespace = namespace or self.ha_namespace
-        device = ip_lib.IPDevice(interface_name, namespace=namespace)
+        device = ip_lib.IPDevice(interface_name, namespace=self.ha_namespace)
         ipv6_lladdr = ip_lib.get_ipv6_lladdr(device.link.address)
 
         if self._should_delete_ipv6_lladdr(ipv6_lladdr):
-            self.driver.configure_ipv6_ra(namespace, interface_name,
+            self.driver.configure_ipv6_ra(self.ha_namespace, interface_name,
                                           n_consts.ACCEPT_RA_DISABLED)
             device.addr.flush(n_consts.IP_VERSION_6)
         else:
             self.driver.configure_ipv6_ra(
-                namespace, interface_name,
+                self.ha_namespace, interface_name,
                 n_consts.ACCEPT_RA_WITHOUT_FORWARDING)
 
         self._remove_vip(ipv6_lladdr)
@@ -354,10 +359,7 @@ class HaRouter(router.RouterInfo):
         if device.addr.list(to=to):
             super(HaRouter, self).remove_floating_ip(device, ip_cidr)
 
-    def internal_network_updated(self, port):
-        interface_name = self.get_internal_device_name(port['id'])
-        ip_cidrs = common_utils.fixed_ip_cidrs(port['fixed_ips'])
-        mtu = port['mtu']
+    def internal_network_updated(self, interface_name, ip_cidrs, mtu):
         self.driver.set_mtu(interface_name, mtu, namespace=self.ns_name,
                             prefix=router.INTERNAL_DEV_PREFIX)
         self._clear_vips(interface_name)
@@ -447,6 +449,15 @@ class HaRouter(router.RouterInfo):
         except common_utils.WaitTimeout:
             pm.disable(sig=str(int(signal.SIGKILL)))
 
+    def update_initial_state(self, callback):
+        addresses = ip_lib.get_devices_with_ip(self.ha_namespace,
+                                               name=self.get_ha_device_name())
+        cidrs = (address['cidr'] for address in addresses)
+        ha_cidr = self._get_primary_vip()
+        state = 'primary' if ha_cidr in cidrs else 'backup'
+        self.ha_state = state
+        callback(self.router_id, state)
+
     @staticmethod
     def _gateway_ports_equal(port1, port2):
         def _get_filtered_dict(d, ignore):
@@ -465,10 +476,10 @@ class HaRouter(router.RouterInfo):
         self._add_gateway_vip(ex_gw_port, interface_name)
         self._disable_ipv6_addressing_on_interface(interface_name)
 
-        # Enable RA and IPv6 forwarding only for master instances. This will
+        # Enable RA and IPv6 forwarding only for primary instances. This will
         # prevent backup routers from sending packets to the upstream switch
         # and disrupt connections.
-        enable = self.ha_state == 'master'
+        enable = self.ha_state == 'primary'
         self._configure_ipv6_params_on_gw(ex_gw_port, self.ns_name,
                                           interface_name, enable)
 
@@ -483,11 +494,11 @@ class HaRouter(router.RouterInfo):
     def external_gateway_removed(self, ex_gw_port, interface_name):
         self._clear_vips(interface_name)
 
-        if self.ha_state == 'master':
+        if self.ha_state == 'primary':
             super(HaRouter, self).external_gateway_removed(ex_gw_port,
                                                            interface_name)
         else:
-            # We are not the master node, so no need to delete ip addresses.
+            # We are not the primary node, so no need to delete ip addresses.
             self.driver.unplug(interface_name,
                                namespace=self.ns_name,
                                prefix=router.EXTERNAL_DEV_PREFIX)
@@ -523,13 +534,13 @@ class HaRouter(router.RouterInfo):
     @runtime.synchronized('enable_radvd')
     def enable_radvd(self, internal_ports=None):
         if (self.keepalived_manager.get_process().active and
-                self.ha_state == 'master'):
+                self.ha_state == 'primary'):
             super(HaRouter, self).enable_radvd(internal_ports)
 
     def external_gateway_link_up(self):
         # Check HA router ha_state for its gateway port link state.
         # 'backup' instance will not link up the gateway port.
-        return self.ha_state == 'master'
+        return self.ha_state == 'primary'
 
     def set_external_gw_port_link_status(self, link_up, set_gw=False):
         link_state = "up" if link_up else "down"
