@@ -20,14 +20,14 @@ from neutron_lib import constants as lib_constants
 from neutron_lib.exceptions import l3 as l3_exc
 from neutron_lib.utils import helpers
 from oslo_log import log as logging
-import six
+from oslo_utils import netutils
+from pyroute2.netlink import exceptions as pyroute2_exc
 
 from neutron._i18n import _
 from neutron.agent.l3 import namespaces
 from neutron.agent.linux import ip_lib
 from neutron.agent.linux import iptables_manager
 from neutron.agent.linux import ra
-from neutron.common import coordination
 from neutron.common import ipv6_utils
 from neutron.common import utils as common_utils
 from neutron.ipam import utils as ipam_utils
@@ -43,8 +43,7 @@ ADDRESS_SCOPE_MARK_ID_MAX = 2048
 DEFAULT_ADDRESS_SCOPE = "noscope"
 
 
-@six.add_metaclass(abc.ABCMeta)
-class BaseRouterInfo(object):
+class BaseRouterInfo(object, metaclass=abc.ABCMeta):
 
     def __init__(self,
                  agent,
@@ -172,14 +171,16 @@ class RouterInfo(BaseRouterInfo):
         return namespaces.RouterNamespace(
             router_id, agent_conf, iface_driver, use_ipv6)
 
-    def is_router_master(self):
+    def is_router_primary(self):
         return True
 
     def _update_routing_table(self, operation, route, namespace):
-        cmd = ['ip', 'route', operation, 'to', route['destination'],
-               'via', route['nexthop']]
-        ip_wrapper = ip_lib.IPWrapper(namespace=namespace)
-        ip_wrapper.netns.execute(cmd, check_exit_code=False)
+        method = (ip_lib.add_ip_route if operation == 'replace' else
+                  ip_lib.delete_ip_route)
+        try:
+            method(namespace, route['destination'], via=route['nexthop'])
+        except (RuntimeError, OSError, pyroute2_exc.NetlinkError):
+            pass
 
     def update_routing_table(self, operation, route):
         self._update_routing_table(operation, route, self.ns_name)
@@ -587,10 +588,7 @@ class RouterInfo(BaseRouterInfo):
                       self.router_id)
             self.radvd.disable()
 
-    def internal_network_updated(self, port):
-        interface_name = self.get_internal_device_name(port['id'])
-        ip_cidrs = common_utils.fixed_ip_cidrs(port['fixed_ips'])
-        mtu = port['mtu']
+    def internal_network_updated(self, interface_name, ip_cidrs, mtu):
         self.driver.set_mtu(interface_name, mtu, namespace=self.ns_name,
                             prefix=INTERNAL_DEV_PREFIX)
         self.driver.init_router_port(
@@ -649,8 +647,12 @@ class RouterInfo(BaseRouterInfo):
         updated_cidrs = []
         for p in updated_ports:
             self._update_internal_ports_cache(p)
-            updated_cidrs += common_utils.fixed_ip_cidrs(p['fixed_ips'])
-            self.internal_network_updated(p)
+            interface_name = self.get_internal_device_name(p['id'])
+            ip_cidrs = common_utils.fixed_ip_cidrs(p['fixed_ips'])
+            LOG.debug("updating internal network for port %s", p)
+            updated_cidrs += ip_cidrs
+            self.internal_network_updated(
+                interface_name, ip_cidrs, p['mtu'])
             enable_ra = enable_ra or self._port_has_ipv6_subnet(p)
 
         # Check if there is any pd prefix update
@@ -983,7 +985,6 @@ class RouterInfo(BaseRouterInfo):
         finally:
             self.update_fip_statuses(fip_statuses)
 
-    @coordination.synchronized('router-lock-ns-{self.ns_name}')
     def process_external(self):
         fip_statuses = {}
         try:
@@ -1078,16 +1079,30 @@ class RouterInfo(BaseRouterInfo):
         # requests that arrive before the filter metadata redirect
         # rule is installed will be dropped.
         mark_metadata_for_internal_interfaces = (
-            '-d 169.254.169.254/32 '
+            '-d %(metadata_cidr)s '
             '-i %(interface_name)s '
             '-p tcp -m tcp --dport 80 '
             '-j MARK --set-xmark %(value)s/%(mask)s' %
-            {'interface_name': INTERNAL_DEV_PREFIX + '+',
+            {'metadata_cidr': lib_constants.METADATA_V4_CIDR,
+             'interface_name': INTERNAL_DEV_PREFIX + '+',
              'value': self.agent_conf.metadata_access_mark,
              'mask': lib_constants.ROUTER_MARK_MASK})
         self.iptables_manager.ipv4['mangle'].add_rule(
             'PREROUTING', mark_metadata_for_internal_interfaces)
 
+        if netutils.is_ipv6_enabled():
+            mark_metadata_v6_for_internal_interfaces = (
+                '-d %(metadata_v6_ip)s/128 '
+                '-i %(interface_name)s '
+                '-p tcp -m tcp --dport 80 '
+                '-j MARK --set-xmark %(value)s/%(mask)s' %
+                {'metadata_v6_ip': lib_constants.METADATA_V6_IP,
+                 'interface_name': INTERNAL_DEV_PREFIX + '+',
+                 'value': self.agent_conf.metadata_access_mark,
+                 'mask': lib_constants.ROUTER_MARK_MASK})
+            self.iptables_manager.ipv6['mangle'].add_rule(
+                'PREROUTING', mark_metadata_v6_for_internal_interfaces)
+
     def _get_port_devicename_scopemark(self, ports, name_generator):
         devicename_scopemark = {lib_constants.IP_VERSION_4: dict(),
                                 lib_constants.IP_VERSION_6: dict()}
@@ -1192,7 +1207,6 @@ class RouterInfo(BaseRouterInfo):
             self.get_address_scope_mark_mask(address_scope))
         iptables_manager.ipv4['nat'].add_rule('snat', rule)
 
-    @coordination.synchronized('router-lock-ns-{self.ns_name}')
     def process_address_scope(self):
         with self.iptables_manager.defer_apply():
             self.process_ports_address_scope_iptables()
