@@ -16,6 +16,7 @@
 import abc
 import collections
 import copy
+import io
 import itertools
 import os
 import re
@@ -27,12 +28,12 @@ from neutron_lib.api.definitions import extra_dhcp_opt as edo_ext
 from neutron_lib import constants
 from neutron_lib import exceptions
 from neutron_lib.utils import file as file_utils
+from oslo_concurrency import processutils
 from oslo_log import log as logging
 from oslo_utils import excutils
 from oslo_utils import fileutils
 from oslo_utils import netutils
 from oslo_utils import uuidutils
-import six
 
 from neutron._i18n import _
 from neutron.agent.common import utils as agent_common_utils
@@ -42,19 +43,11 @@ from neutron.agent.linux import iptables_manager
 from neutron.cmd import runtime_checks as checks
 from neutron.common import utils as common_utils
 from neutron.ipam import utils as ipam_utils
+from neutron.privileged.agent.linux import dhcp as priv_dhcp
 
 LOG = logging.getLogger(__name__)
 
-UDP = 'udp'
-TCP = 'tcp'
 DNS_PORT = 53
-DHCPV4_PORT = 67
-DHCPV6_PORT = 547
-METADATA_DEFAULT_PREFIX = 16
-METADATA_DEFAULT_IP = '169.254.169.254'
-METADATA_DEFAULT_CIDR = '%s/%d' % (METADATA_DEFAULT_IP,
-                                   METADATA_DEFAULT_PREFIX)
-METADATA_PORT = 80
 WIN2k3_STATIC_DNS = 249
 NS_PREFIX = 'qdhcp-'
 DNSMASQ_SERVICE_NAME = 'dnsmasq'
@@ -66,22 +59,6 @@ HOST_DHCPV6_TAG = 'tag:dhcpv6,'
 DHCP_OPT_CLIENT_ID_NUM = 61
 
 
-def port_requires_dhcp_configuration(port):
-    if not getattr(port, 'device_owner', None):
-        # We can't check if port needs dhcp entry, so it will be better
-        # to create one
-        return True
-    # TODO(slaweq): define this list as a constant in neutron_lib.constants
-    # NOTE(slaweq): Not all port types which belongs e.g. to the routers can be
-    # excluded from that list. For some of them, like router interfaces used to
-    # plug subnet to the router should be configured in dnsmasq to provide DNS
-    # naming resolution. Otherwise it may slowdown e.g. traceroutes from the VM
-    return port.device_owner not in [
-        constants.DEVICE_OWNER_ROUTER_HA_INTF,
-        constants.DEVICE_OWNER_FLOATINGIP,
-        constants.DEVICE_OWNER_DHCP]
-
-
 class DictModel(collections.abc.MutableMapping):
     """Convert dict into an object that provides attribute access to values."""
 
@@ -157,6 +134,7 @@ class DictModel(collections.abc.MutableMapping):
         return type(self)(self)
 
     def __deepcopy__(self, memo):
+        # pylint: disable=no-value-for-parameter
         cls = self.__class__
         result = cls.__new__(cls)
         memo[id(self)] = result
@@ -177,8 +155,7 @@ class NetModel(DictModel):
         return self._ns_name
 
 
-@six.add_metaclass(abc.ABCMeta)
-class DhcpBase(object):
+class DhcpBase(object, metaclass=abc.ABCMeta):
 
     def __init__(self, conf, network, process_monitor,
                  version=None, plugin=None):
@@ -232,8 +209,7 @@ class DhcpBase(object):
         raise NotImplementedError()
 
 
-@six.add_metaclass(abc.ABCMeta)
-class DhcpLocalProcess(DhcpBase):
+class DhcpLocalProcess(DhcpBase, metaclass=abc.ABCMeta):
     PORTS = []
 
     def __init__(self, conf, network, process_monitor, version=None,
@@ -309,7 +285,7 @@ class DhcpLocalProcess(DhcpBase):
             common_utils.wait_until_true(lambda: not self.active)
         if not retain_port:
             self._destroy_namespace_and_port()
-            self._remove_config_files()
+        self._remove_config_files()
 
     def _destroy_namespace_and_port(self):
         try:
@@ -350,6 +326,9 @@ class DhcpLocalProcess(DhcpBase):
         interface_file_path = self.get_conf_file_name('interface')
         file_utils.replace_file(interface_file_path, value)
 
+    def get_metadata_bind_interface(self, port):
+        return self.device_manager.get_interface_name(self.network, port)
+
     @property
     def active(self):
         return self._get_process_manager().active
@@ -364,9 +343,13 @@ class Dnsmasq(DhcpLocalProcess):
     # on the Neutron port used for DHCP.  These are provided as a convenience
     # for users of this class.
     PORTS = {constants.IP_VERSION_4:
-             [(UDP, DNS_PORT), (TCP, DNS_PORT), (UDP, DHCPV4_PORT)],
+             [(constants.PROTO_NAME_UDP, DNS_PORT),
+              (constants.PROTO_NAME_TCP, DNS_PORT),
+              (constants.PROTO_NAME_UDP, constants.DHCP_RESPONSE_PORT)],
              constants.IP_VERSION_6:
-             [(UDP, DNS_PORT), (TCP, DNS_PORT), (UDP, DHCPV6_PORT)],
+             [(constants.PROTO_NAME_UDP, DNS_PORT),
+              (constants.PROTO_NAME_TCP, DNS_PORT),
+              (constants.PROTO_NAME_UDP, constants.DHCPV6_RESPONSE_PORT)],
              }
 
     _SUBNET_TAG_PREFIX = 'subnet-%s'
@@ -479,8 +462,7 @@ class Dnsmasq(DhcpLocalProcess):
             cmd.append('--dhcp-option-force=option:T2,%ds' %
                        self.conf.dhcp_rebinding_time)
 
-        cmd.append('--conf-file=%s' %
-                   (self.conf.dnsmasq_config_file.strip() or '/dev/null'))
+        cmd.append('--conf-file=%s' % self.conf.dnsmasq_config_file)
         for server in self.conf.dnsmasq_dns_servers:
             cmd.append('--server=%s' % server)
 
@@ -534,7 +516,8 @@ class Dnsmasq(DhcpLocalProcess):
 
     def _is_dhcp_release6_supported(self):
         if self._IS_DHCP_RELEASE6_SUPPORTED is None:
-            self._IS_DHCP_RELEASE6_SUPPORTED = checks.dhcp_release6_supported()
+            self._IS_DHCP_RELEASE6_SUPPORTED = (
+                priv_dhcp.dhcp_release6_supported())
             if not self._IS_DHCP_RELEASE6_SUPPORTED:
                 LOG.warning("dhcp_release6 is not present on this system, "
                             "will not call it again.")
@@ -549,24 +532,27 @@ class Dnsmasq(DhcpLocalProcess):
     def _release_lease(self, mac_address, ip, ip_version, client_id=None,
                        server_id=None, iaid=None):
         """Release a DHCP lease."""
-        if ip_version == constants.IP_VERSION_6:
-            if not self._is_dhcp_release6_supported():
-                return
-            cmd = ['dhcp_release6', '--iface', self.interface_name,
-                   '--ip', ip, '--client-id', client_id,
-                   '--server-id', server_id, '--iaid', iaid]
-        else:
-            cmd = ['dhcp_release', self.interface_name, ip, mac_address]
-            if client_id:
-                cmd.append(client_id)
-        ip_wrapper = ip_lib.IPWrapper(namespace=self.network.namespace)
         try:
-            ip_wrapper.netns.execute(cmd, run_as_root=True)
-        except RuntimeError as e:
+            if ip_version == constants.IP_VERSION_6:
+                if not self._is_dhcp_release6_supported():
+                    return
+
+                params = {'interface_name': self.interface_name,
+                          'ip_address': ip, 'client_id': client_id,
+                          'server_id': server_id, 'iaid': iaid,
+                          'namespace': self.network.namespace}
+                priv_dhcp.dhcp_release6(**params)
+            else:
+                params = {'interface_name': self.interface_name,
+                          'ip_address': ip, 'mac_address': mac_address,
+                          'client_id': client_id,
+                          'namespace': self.network.namespace}
+                priv_dhcp.dhcp_release(**params)
+        except (processutils.ProcessExecutionError, OSError) as e:
             # when failed to release single lease there's
             # no need to propagate error further
-            LOG.warning('DHCP release failed for %(cmd)s. '
-                        'Reason: %(e)s', {'cmd': cmd, 'e': e})
+            LOG.warning('DHCP release failed for params %(params)s. '
+                        'Reason: %(e)s', {'params': params, 'e': e})
 
     def _output_config_files(self):
         self._output_hosts_file()
@@ -736,9 +722,6 @@ class Dnsmasq(DhcpLocalProcess):
                        if subnet.ip_version == 6)
 
         for port in self.network.ports:
-            if not port_requires_dhcp_configuration(port):
-                continue
-
             fixed_ips = self._sort_fixed_ips_for_dnsmasq(port.fixed_ips,
                                                          v6_nets)
             # TODO(hjensas): Drop this conditional and option once distros
@@ -783,7 +766,7 @@ class Dnsmasq(DhcpLocalProcess):
         epoch-timestamp mac_addr ip_addr hostname client-ID
         """
         filename = self.get_conf_file_name('leases')
-        buf = six.StringIO()
+        buf = io.StringIO()
 
         LOG.debug('Building initial lease file: %s', filename)
         # we make up a lease time for the database entry
@@ -798,50 +781,17 @@ class Dnsmasq(DhcpLocalProcess):
         dhcpv4_enabled_subnet_ids = [
             s.id for s in self._get_all_subnets(self.network)
             if s.enable_dhcp and s.ip_version == constants.IP_VERSION_4]
-        dhcpv6_enabled_subnet_ids = [
-            s.id for s in self._get_all_subnets(self.network)
-            if s.enable_dhcp and s.ip_version == constants.IP_VERSION_6]
-
-        existing_ipv6_leases = {}
-        if os.path.isfile(filename):
-            # The IPv6 leases can't be generated as their IAID is unknown. To
-            # not loose active leases, read the existing leases and add them to
-            # the generated file.
-            LOG.debug('Reading IPv6 leases from existing lease file.')
-            with open(filename) as leasefile:
-                for line in leasefile:
-                    if line.startswith('duid '):
-                        # Keep the DUID
-                        buf.write(line)
-                        continue
-                    try:
-                        ts, mac, ip, host, iaid = line.split(' ')
-                    except ValueError:
-                        # not the correct format for a lease, skip this line
-                        continue
-
-                    if netaddr.valid_ipv6(ip):
-                        existing_ipv6_leases[netaddr.IPAddress(ip)] = line
-
         for host_tuple in self._iter_hosts():
             port, alloc, hostname, name, no_dhcp, no_opts, tag = host_tuple
-
-            if no_dhcp:
+            # don't write ip address which belongs to a dhcp disabled subnet
+            # or an IPv6 subnet.
+            if no_dhcp or alloc.subnet_id not in dhcpv4_enabled_subnet_ids:
                 continue
 
-            if alloc.subnet_id in dhcpv4_enabled_subnet_ids:
-                # all that matters is the mac address and IP. the hostname and
-                # client ID will be overwritten on the next renewal.
-                buf.write('%s %s %s * *\n' %
-                          (timestamp, port.mac_address, alloc.ip_address))
-            elif (alloc.subnet_id in dhcpv6_enabled_subnet_ids and
-                  netaddr.IPAddress(alloc.ip_address) in existing_ipv6_leases):
-                # Keep the existing IPv6 lease if the port still exists and is
-                # still configured for DHCPv6
-                buf.write(
-                    existing_ipv6_leases[netaddr.IPAddress(alloc.ip_address)]
-                )
-
+            # all that matters is the mac address and IP. the hostname and
+            # client ID will be overwritten on the next renewal.
+            buf.write('%s %s %s * *\n' %
+                      (timestamp, port.mac_address, alloc.ip_address))
         contents = buf.getvalue()
         file_utils.replace_file(filename, contents)
         LOG.debug('Done building initial lease file %s with contents:\n%s',
@@ -873,7 +823,7 @@ class Dnsmasq(DhcpLocalProcess):
         should receive a dhcp lease, the hosts resolution in itself is
         defined by the `_output_addn_hosts_file` method.
         """
-        buf = six.StringIO()
+        buf = io.StringIO()
         filename = self.get_conf_file_name('host')
 
         LOG.debug('Building host file: %s', filename)
@@ -937,8 +887,8 @@ class Dnsmasq(DhcpLocalProcess):
         leases = set()
         try:
             with open(filename) as f:
-                for l in f.readlines():
-                    host = l.strip().split(',')
+                for line in f.readlines():
+                    host = line.strip().split(',')
                     mac = host[0]
                     client_id = None
                     if host[1].startswith('set:'):
@@ -956,7 +906,7 @@ class Dnsmasq(DhcpLocalProcess):
             LOG.debug('Error while reading hosts file %s', filename)
         return leases
 
-    def _read_leases_file_leases(self, filename, ip_version=None):
+    def _read_leases_file_leases(self, filename):
         """Read dnsmasq dhcp leases file
 
         Read information from leases file, which is needed to pass to
@@ -991,7 +941,6 @@ class Dnsmasq(DhcpLocalProcess):
         dnsmasq-discuss/2016q2/010595.html
 
         :param filename: leases file
-        :param ip_version: IP version of entries to return, or None for all
         :return: dict, keys are IP(v6) addresses, values are dicts containing
                 iaid, client_id and server_id
         """
@@ -999,27 +948,23 @@ class Dnsmasq(DhcpLocalProcess):
         server_id = None
         if os.path.exists(filename):
             with open(filename) as f:
-                for l in f.readlines():
-                    if l.startswith('duid'):
+                for line in f.readlines():
+                    if line.startswith('duid'):
                         if not server_id:
-                            server_id = l.strip().split()[1]
-                            continue
+                            server_id = line.strip().split()[1]
                         else:
                             LOG.warning('Multiple DUID entries in %s '
                                         'lease file, dnsmasq is possibly '
                                         'not functioning properly',
                                         filename)
-                            continue
-                    parts = l.strip().split()
+                        continue
+                    parts = line.strip().split()
                     if len(parts) != 5:
                         LOG.warning('Invalid lease entry %s found in %s '
                                     'lease file, ignoring', parts, filename)
                         continue
                     (iaid, ip, client_id) = parts[1], parts[2], parts[4]
                     ip = ip.strip('[]')
-                    if (ip_version and
-                            netaddr.IPAddress(ip).version != ip_version):
-                        continue
                     leases[ip] = {'iaid': iaid,
                                   'client_id': client_id,
                                   'server_id': server_id
@@ -1116,7 +1061,7 @@ class Dnsmasq(DhcpLocalProcess):
         Each line in this file is in the same form as a standard /etc/hosts
         file.
         """
-        buf = six.StringIO()
+        buf = io.StringIO()
         for host_tuple in self._iter_hosts():
             port, alloc, hostname, fqdn, no_dhcp, no_opts, tag = host_tuple
             # It is compulsory to write the `fqdn` before the `hostname` in
@@ -1200,11 +1145,11 @@ class Dnsmasq(DhcpLocalProcess):
                 subnet_dhcp_ip = subnet_to_interface_ip.get(subnet.id)
                 if subnet_dhcp_ip:
                     host_routes.append(
-                        '%s/32,%s' % (METADATA_DEFAULT_IP, subnet_dhcp_ip)
+                        '%s,%s' % (constants.METADATA_CIDR, subnet_dhcp_ip)
                     )
             elif not isolated_subnets[subnet.id] and gateway:
                 host_routes.append(
-                    '%s/32,%s' % (METADATA_DEFAULT_IP, gateway)
+                    '%s,%s' % (constants.METADATA_CIDR, gateway)
                 )
 
             if subnet.ip_version == 4:
@@ -1312,7 +1257,6 @@ class Dnsmasq(DhcpLocalProcess):
     def _format_option(self, ip_version, tag, option, *args):
         """Format DHCP option by option name or code."""
         option = str(option)
-        option = option.split("\n", 1)[0]
         pattern = "(tag:(.*),)?(.*)$"
         matches = re.match(pattern, option)
         extra_tag = matches.groups()[0]
@@ -1328,11 +1272,10 @@ class Dnsmasq(DhcpLocalProcess):
         elif not option.isdigit():
             option = 'option:%s' % option
         if extra_tag:
-            tags = ['tag:' + tag, extra_tag[:-1], '%s' % option]
+            tags = ('tag:' + tag, extra_tag[:-1], '%s' % option)
         else:
-            tags = ['tag:' + tag, '%s' % option]
-
-        return ','.join(tags + [v.split("\n", 1)[0] for v in args])
+            tags = ('tag:' + tag, '%s' % option)
+        return ','.join(tags + args)
 
     @staticmethod
     def _convert_to_literal_addrs(ip_version, ips):
@@ -1366,7 +1309,7 @@ class Dnsmasq(DhcpLocalProcess):
     @staticmethod
     def has_metadata_subnet(subnets):
         """Check if the subnets has a metadata subnet."""
-        meta_cidr = netaddr.IPNetwork(METADATA_DEFAULT_CIDR)
+        meta_cidr = netaddr.IPNetwork(constants.METADATA_V4_SUBNET)
         if any(netaddr.IPNetwork(s.cidr) in meta_cidr
                for s in subnets):
             return True
@@ -1387,11 +1330,9 @@ class Dnsmasq(DhcpLocalProcess):
         providing access to the metadata service via logical routers built
         with 3rd party backends.
         """
-        # Only IPv4 subnets, with dhcp enabled, will use the metadata proxy.
         all_subnets = cls._get_all_subnets(network)
-        v4_dhcp_subnets = [s for s in all_subnets
-                           if s.ip_version == 4 and s.enable_dhcp]
-        if not v4_dhcp_subnets:
+        dhcp_subnets = [s for s in all_subnets if s.enable_dhcp]
+        if not dhcp_subnets:
             return False
 
         if conf.force_metadata:
@@ -1405,7 +1346,7 @@ class Dnsmasq(DhcpLocalProcess):
             return True
 
         isolated_subnets = cls.get_isolated_subnets(network)
-        return any(isolated_subnets[s.id] for s in v4_dhcp_subnets)
+        return any(isolated_subnets[s.id] for s in dhcp_subnets)
 
 
 class DeviceManager(object):
@@ -1771,7 +1712,9 @@ class DeviceManager(object):
                     ip_cidrs.append('%s/%s' % (gateway, net.prefixlen))
 
         if self.conf.force_metadata or self.conf.enable_isolated_metadata:
-            ip_cidrs.append(METADATA_DEFAULT_CIDR)
+            ip_cidrs.append(constants.METADATA_CIDR)
+            if netutils.is_ipv6_enabled():
+                ip_cidrs.append(constants.METADATA_V6_CIDR)
 
         self.driver.init_l3(interface_name, ip_cidrs,
                             namespace=network.namespace)
@@ -1801,11 +1744,11 @@ class DeviceManager(object):
 
     def fill_dhcp_udp_checksums(self, namespace):
         """Ensure DHCP reply packets always have correct UDP checksums."""
-        iptables_mgr = iptables_manager.IptablesManager(
-            use_ipv6=netutils.is_ipv6_enabled(), nat=False,
-            namespace=namespace)
+        iptables_mgr = iptables_manager.IptablesManager(use_ipv6=True,
+                                                        nat=False,
+                                                        namespace=namespace)
         ipv4_rule = ('-p udp -m udp --dport %d -j CHECKSUM --checksum-fill'
-                     % constants.DHCP_RESPONSE_PORT)
+                     % constants.DHCP_CLIENT_PORT)
         ipv6_rule = ('-p udp -m udp --dport %d -j CHECKSUM --checksum-fill'
                      % constants.DHCPV6_CLIENT_PORT)
         iptables_mgr.ipv4['mangle'].add_rule('POSTROUTING', ipv4_rule)
