@@ -22,7 +22,6 @@ from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import fileutils
 import psutil
-import six
 
 from neutron.agent.linux import ip_lib
 from neutron.agent.linux import utils
@@ -37,8 +36,7 @@ agent_cfg.register_external_process_opts()
 agent_cfg.register_process_monitor_opts(cfg.CONF)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class MonitoredProcess(object):
+class MonitoredProcess(object, metaclass=abc.ABCMeta):
     @abc.abstractproperty
     def active(self):
         """Boolean representing the running state of the process."""
@@ -113,10 +111,9 @@ class ProcessManager(MonitoredProcess):
                 utils.execute(cmd, run_as_root=self.run_as_root)
                 # In the case of shutting down, remove the pid file
                 if sig == '9':
-                    utils.delete_if_exists(self.get_pid_file_name(),
-                                           run_as_root=self.run_as_root)
+                    fileutils.delete_if_exists(self.get_pid_file_name())
         elif pid:
-            LOG.debug('%(service)s process for %(uuid)s pid %(pid)d is stale, '
+            LOG.debug('%{service}s process for %(uuid)s pid %(pid)d is stale, '
                       'ignoring signal %(signal)s',
                       {'service': self.service, 'uuid': self.uuid,
                        'pid': pid, 'signal': sig})
