@@ -22,15 +22,14 @@ from neutron_lib import exceptions
 from oslo_log import log as logging
 from oslo_utils import excutils
 from pyroute2.netlink import exceptions as pyroute2_exc
-import six
 
 from neutron.agent.common import ovs_lib
-from neutron.agent.linux import ethtool
 from neutron.agent.linux import ip_lib
 from neutron.common import utils
 from neutron.conf.plugins.ml2.drivers import ovs_conf
 from neutron.plugins.ml2.drivers.openvswitch.agent.common \
     import constants as ovs_const
+from neutron.privileged.agent.linux import ethtool
 
 LOG = logging.getLogger(__name__)
 
@@ -40,8 +39,7 @@ def _get_veth(name1, name2, namespace2):
             ip_lib.IPDevice(name2, namespace=namespace2))
 
 
-@six.add_metaclass(abc.ABCMeta)
-class LinuxInterfaceDriver(object):
+class LinuxInterfaceDriver(object, metaclass=abc.ABCMeta):
 
     DEV_NAME_LEN = constants.LINUX_DEV_LEN
     DEV_NAME_PREFIX = constants.TAP_DEVICE_PREFIX
@@ -441,8 +439,8 @@ class OVSInterfaceDriver(LinuxInterfaceDriver):
             # ovs-dpdk does not do checksum calculations for veth interface
             # (bug 1832021)
             if self.conf.OVS.datapath_type == ovs_const.OVS_DATAPATH_NETDEV:
-                ethtool.Ethtool.offload(ns_dev.name, rx=False, tx=False,
-                                        namespace=namespace)
+                ethtool.offload(ns_dev.name, rx=False, tx=False,
+                                namespace=namespace)
             root_dev.link.set_up()
 
     def unplug(self, device_name, bridge=None, namespace=None, prefix=None):
