@@ -14,7 +14,6 @@
 #    under the License.
 
 import errno
-from os import path
 import re
 import threading
 import time
@@ -36,7 +35,6 @@ from neutron._i18n import _
 from neutron.agent.common import utils
 from neutron.common import utils as common_utils
 from neutron.privileged.agent.linux import ip_lib as privileged
-from neutron.privileged.agent.linux import utils as priv_utils
 
 LOG = logging.getLogger(__name__)
 
@@ -553,7 +551,7 @@ class IpAddrCommand(IpDeviceCommandBase):
             if not common_utils.is_cidr_host(cidr):
                 kwargs['mask'] = common_utils.cidr_mask_length(cidr)
         if scope:
-            kwargs['scope'] = scope
+            kwargs['scope'] = IP_ADDRESS_SCOPE_NAME[scope]
         if ip_version:
             kwargs['family'] = common_utils.get_socket_address_family(
                 ip_version)
@@ -933,16 +931,9 @@ def network_namespace_exists(namespace, try_is_ready=False, **kwargs):
                          is ready to be operated.
     :param kwargs: Callers add any filters they use as kwargs
     """
-    if not namespace:
-        return False
-
     if not try_is_ready:
-        nspath = kwargs.get('nspath') or netns.NETNS_RUN_DIR
-        nspath += '/' + namespace
-        if cfg.CONF.AGENT.use_helper_for_ns_read:
-            return priv_utils.path_exists(nspath)
-        else:
-            return path.exists(nspath)
+        output = list_network_namespaces(**kwargs)
+        return namespace in output
 
     try:
         privileged.open_namespace(namespace)
@@ -1349,37 +1340,35 @@ def _parse_ip_address(pyroute2_address, device_name):
             'event': event}
 
 
-def get_devices_with_ip(namespace, name=None, **kwargs):
+def _parse_link_device(namespace, device, **kwargs):
+    """Parse pytoute2 link device information
+
+    For each link device, the IP address information is retrieved and returned
+    in a dictionary.
+    IP address scope: http://linux-ip.net/html/tools-ip-address.html
+    """
     retval = []
+    name = get_attr(device, 'IFLA_IFNAME')
+    ip_addresses = privileged.get_ip_addresses(namespace,
+                                               index=device['index'],
+                                               **kwargs)
+    for ip_address in ip_addresses:
+        retval.append(_parse_ip_address(ip_address, name))
+    return retval
+
+
+def get_devices_with_ip(namespace, name=None, **kwargs):
     link_args = {}
     if name:
         link_args['ifname'] = name
     scope = kwargs.pop('scope', None)
     if scope:
         kwargs['scope'] = IP_ADDRESS_SCOPE_NAME[scope]
-
-    if not link_args:
-        ip_addresses = privileged.get_ip_addresses(namespace, **kwargs)
-    else:
-        device = get_devices_info(namespace, **link_args)
-        if not device:
-            return retval
-        ip_addresses = privileged.get_ip_addresses(
-            namespace, index=device[0]['index'], **kwargs)
-
-    devices = {}  # {device index: name}
-    for ip_address in ip_addresses:
-        index = ip_address['index']
-        name = get_attr(ip_address, 'IFA_LABEL') or devices.get(index)
-        if not name:
-            device = get_devices_info(namespace, index=index)
-            if not device:
-                continue
-            name = device[0]['name']
-
-        retval.append(_parse_ip_address(ip_address, name))
-        devices[index] = name
-
+    devices = privileged.get_link_devices(namespace, **link_args)
+    retval = []
+    for parsed_ips in (_parse_link_device(namespace, device, **kwargs)
+                       for device in devices):
+        retval += parsed_ips
     return retval
 
 
@@ -1409,6 +1398,10 @@ def get_devices_info(namespace, **kwargs):
                                                    'IFLA_VXLAN_LINK')
             elif ret['kind'] == 'vlan':
                 ret['vlan_id'] = get_attr(ifla_data, 'IFLA_VLAN_ID')
+            elif ret['kind'] == 'bridge':
+                ret['stp'] = get_attr(ifla_data, 'IFLA_BR_STP_STATE')
+                ret['forward_delay'] = get_attr(ifla_data,
+                                                'IFLA_BR_FORWARD_DELAY')
         retval[device['index']] = ret
 
     for device in retval.values():
