@@ -429,18 +429,16 @@ class IptablesFirewallDriver(firewall.FirewallDriver):
                     if self.enable_ipset:
                         port_sg_rules.append(rule)
                         break
-                    else:
-                        port_sg_rules.extend(
-                            self._expand_sg_rule_with_remote_ips(
-                                rule, port, constants.INGRESS_DIRECTION))
-                        if port_sg_rules:
-                            break
-                        else:
-                            port_sg_rules.extend(
-                                self._expand_sg_rule_with_remote_ips(
-                                    rule, port, constants.EGRESS_DIRECTION))
-                            if port_sg_rules:
-                                break
+                    port_sg_rules.extend(
+                        self._expand_sg_rule_with_remote_ips(
+                            rule, port, constants.INGRESS_DIRECTION))
+                    if port_sg_rules:
+                        break
+                    port_sg_rules.extend(
+                        self._expand_sg_rule_with_remote_ips(
+                            rule, port, constants.EGRESS_DIRECTION))
+                    if port_sg_rules:
+                        break
         return port_sg_rules
 
     @staticmethod
@@ -994,8 +992,7 @@ class IptablesFirewallDriver(firewall.FirewallDriver):
             self._clean_deleted_remote_sg_members_conntrack_entries()
 
     def _get_sg_members(self, sg_info, sg_id, ethertype):
-        ip_mac_addresses = sg_info.get(sg_id, {}).get(ethertype, [])
-        return set([ip_mac[0] for ip_mac in ip_mac_addresses])
+        return set(sg_info.get(sg_id, {}).get(ethertype, []))
 
     def filter_defer_apply_off(self):
         if self._defer_apply:
