@@ -308,8 +308,7 @@ class IptablesManager(object):
     _random_fully = None
 
     def __init__(self, _execute=None, state_less=False, use_ipv6=False,
-                 nat=True, namespace=None, binary_name=binary_name,
-                 external_lock=True):
+                 nat=True, namespace=None, binary_name=binary_name):
         if _execute:
             self.execute = _execute
         else:
@@ -319,7 +318,6 @@ class IptablesManager(object):
         self.namespace = namespace
         self.iptables_apply_deferred = False
         self.wrap_name = binary_name[:16]
-        self.external_lock = external_lock
 
         self.ipv4 = {'filter': IptablesTable(binary_name=self.wrap_name)}
         self.ipv6 = {'filter': IptablesTable(binary_name=self.wrap_name)}
@@ -374,9 +372,12 @@ class IptablesManager(object):
     def initialize_nat_table(self):
         self.ipv4.update(
             {'nat': IptablesTable(binary_name=self.wrap_name)})
+        self.ipv6.update(
+            {'nat': IptablesTable(binary_name=self.wrap_name)})
 
         builtin_chains = {
-            4: {'nat': ['PREROUTING', 'OUTPUT', 'POSTROUTING']}}
+            4: {'nat': ['PREROUTING', 'OUTPUT', 'POSTROUTING']},
+            6: {'nat': ['PREROUTING']}}
         self._configure_builtin_chains(builtin_chains)
 
         # Add a neutron-postrouting-bottom chain. It's intended to be
@@ -462,8 +463,7 @@ class IptablesManager(object):
         # NOTE(ihrachys) we may get rid of the lock once all supported
         # platforms get iptables with 999eaa241212d3952ddff39a99d0d55a74e3639e
         # ("iptables-restore: support acquiring the lock.")
-        with lockutils.lock(lock_name, runtime.SYNCHRONIZED_PREFIX,
-                            external=self.external_lock):
+        with lockutils.lock(lock_name, runtime.SYNCHRONIZED_PREFIX, True):
             first = self._apply_synchronized()
             if not cfg.CONF.AGENT.debug_iptables_rules:
                 return first
@@ -851,7 +851,7 @@ def _generate_chain_diff_iptables_commands(chain, old_chain_rules,
         if line.startswith('?'):
             # skip ? because that's a guide string for intraline differences
             continue
-        elif line.startswith('-'):  # line deleted
+        if line.startswith('-'):  # line deleted
             statements.append('-D %s %d' % (chain, old_index))
             # since we are removing a line from the old rules, we
             # backup the index by 1
