@@ -32,7 +32,6 @@ from oslo_utils import netutils
 from neutron._i18n import _
 from neutron.agent.common import ovs_lib
 from neutron.agent import firewall
-from neutron.agent.linux import ip_conntrack
 from neutron.agent.linux.openvswitch_firewall import constants as ovsfw_consts
 from neutron.agent.linux.openvswitch_firewall import exceptions
 from neutron.agent.linux.openvswitch_firewall import iptables
@@ -477,12 +476,13 @@ class OVSFirewallDriver(firewall.FirewallDriver):
         """
         self.permitted_ethertypes = cfg.CONF.SECURITYGROUP.permitted_ethertypes
         self.int_br = self.initialize_bridge(integration_bridge)
-        self._initialize_sg()
+        self.sg_port_map = SGPortMap()
+        self.conj_ip_manager = ConjIPFlowManager(self)
+        self.sg_to_delete = set()
         self._update_cookie = None
         self._deferred = False
         self.iptables_helper = iptables.Helper(self.int_br.br)
         self.iptables_helper.load_driver_if_needed()
-        self.ipconntrack = ip_conntrack.OvsIpConntrackManager()
         self._initialize_firewall()
 
         callbacks_registry.subscribe(
@@ -492,14 +492,8 @@ class OVSFirewallDriver(firewall.FirewallDriver):
 
     def _init_firewall_callback(self, resource, event, trigger, payload=None):
         LOG.info("Reinitialize Openvswitch firewall after OVS restart.")
-        self._initialize_sg()
         self._initialize_firewall()
 
-    def _initialize_sg(self):
-        self.sg_port_map = SGPortMap()
-        self.conj_ip_manager = ConjIPFlowManager(self)
-        self.sg_to_delete = set()
-
     def _initialize_firewall(self):
         self._drop_all_unmatched_flows()
         self._initialize_common_flows()
@@ -613,12 +607,6 @@ class OVSFirewallDriver(firewall.FirewallDriver):
         return get_physical_network_from_other_config(
             self.int_br.br, port_name)
 
-    def _delete_invalid_conntrack_entries_for_port(self, port, of_port):
-        port['of_port'] = of_port
-        for ethertype in [lib_const.IPv4, lib_const.IPv6]:
-            self.ipconntrack.delete_conntrack_state_by_remote_ips(
-                [port], ethertype, set(), mark=ovsfw_consts.CT_MARK_INVALID)
-
     def get_ofport(self, port):
         port_id = port['device']
         return self.sg_port_map.ports.get(port_id)
@@ -673,7 +661,6 @@ class OVSFirewallDriver(firewall.FirewallDriver):
                 self._update_flows_for_port(of_port, old_of_port)
             else:
                 self._set_port_filters(of_port)
-            self._delete_invalid_conntrack_entries_for_port(port, of_port)
         except exceptions.OVSFWPortNotFound as not_found_error:
             LOG.info("port %(port_id)s does not exist in ovsdb: %(err)s.",
                      {'port_id': port['device'],
@@ -713,8 +700,6 @@ class OVSFirewallDriver(firewall.FirewallDriver):
             else:
                 self._set_port_filters(of_port)
 
-            self._delete_invalid_conntrack_entries_for_port(port, of_port)
-
         except exceptions.OVSFWPortNotFound as not_found_error:
             LOG.info("port %(port_id)s does not exist in ovsdb: %(err)s.",
                      {'port_id': port['device'],
@@ -908,36 +893,19 @@ class OVSFirewallDriver(firewall.FirewallDriver):
         self._initialize_egress(port)
         self._initialize_ingress(port)
 
-    def _initialize_egress_ipv6_icmp(self, port, allowed_pairs):
-        allowed_pairs = allowed_pairs.union({(port.mac, port.lla_address)})
-        for mac_addr, ip_addr in allowed_pairs:
-            for icmp_type in firewall.ICMPV6_ALLOWED_EGRESS_TYPES:
-                self._add_flow(
-                    table=ovs_consts.BASE_EGRESS_TABLE,
-                    priority=95,
-                    in_port=port.ofport,
-                    reg_port=port.ofport,
-                    dl_type=lib_const.ETHERTYPE_IPV6,
-                    nw_proto=lib_const.PROTO_NUM_IPV6_ICMP,
-                    icmp_type=icmp_type,
-                    dl_src=mac_addr,
-                    ipv6_src=ip_addr,
-                    actions='resubmit(,%d)' % (
-                        ovs_consts.ACCEPTED_EGRESS_TRAFFIC_NORMAL_TABLE)
-                )
-            for icmp_type in firewall.ICMPV6_RESTRICTED_EGRESS_TYPES:
-                self._add_flow(
-                    table=ovs_consts.BASE_EGRESS_TABLE,
-                    priority=95,
-                    in_port=port.ofport,
-                    reg_port=port.ofport,
-                    dl_type=lib_const.ETHERTYPE_IPV6,
-                    nw_proto=lib_const.PROTO_NUM_IPV6_ICMP,
-                    icmp_type=icmp_type,
-                    nd_target=ip_addr,
-                    actions='resubmit(,%d)' % (
-                        ovs_consts.ACCEPTED_EGRESS_TRAFFIC_NORMAL_TABLE)
-                )
+    def _initialize_egress_ipv6_icmp(self, port):
+        for icmp_type in firewall.ICMPV6_ALLOWED_EGRESS_TYPES:
+            self._add_flow(
+                table=ovs_consts.BASE_EGRESS_TABLE,
+                priority=95,
+                in_port=port.ofport,
+                reg_port=port.ofport,
+                dl_type=lib_const.ETHERTYPE_IPV6,
+                nw_proto=lib_const.PROTO_NUM_IPV6_ICMP,
+                icmp_type=icmp_type,
+                actions='resubmit(,%d)' % (
+                    ovs_consts.ACCEPTED_EGRESS_TRAFFIC_NORMAL_TABLE)
+            )
 
     def _initialize_egress_no_port_security(self, port_id, ovs_ports=None):
         try:
@@ -1010,11 +978,12 @@ class OVSFirewallDriver(firewall.FirewallDriver):
 
     def _initialize_egress(self, port):
         """Identify egress traffic and send it to egress base"""
+        self._initialize_egress_ipv6_icmp(port)
 
         # Apply mac/ip pairs for IPv4
-        allowed_mac_ipv4_pairs = port.allowed_pairs_v4.union(
+        allowed_pairs = port.allowed_pairs_v4.union(
             {(port.mac, ip_addr) for ip_addr in port.ipv4_addresses})
-        for mac_addr, ip_addr in allowed_mac_ipv4_pairs:
+        for mac_addr, ip_addr in allowed_pairs:
             self._add_flow(
                 table=ovs_consts.BASE_EGRESS_TABLE,
                 priority=95,
@@ -1040,10 +1009,9 @@ class OVSFirewallDriver(firewall.FirewallDriver):
             )
 
         # Apply mac/ip pairs for IPv6
-        allowed_mac_ipv6_pairs = port.allowed_pairs_v6.union(
+        allowed_pairs = port.allowed_pairs_v6.union(
             {(port.mac, ip_addr) for ip_addr in port.ipv6_addresses})
-        self._initialize_egress_ipv6_icmp(port, allowed_mac_ipv6_pairs)
-        for mac_addr, ip_addr in allowed_mac_ipv6_pairs:
+        for mac_addr, ip_addr in allowed_pairs:
             self._add_flow(
                 table=ovs_consts.BASE_EGRESS_TABLE,
                 priority=65,
@@ -1058,30 +1026,21 @@ class OVSFirewallDriver(firewall.FirewallDriver):
             )
 
         # DHCP discovery
-        additional_ipv4_filters = [
-            {"dl_src": mac, "nw_src": ip}
-            for mac, ip in (*allowed_mac_ipv4_pairs,
-                            (port.mac, '0.0.0.0'),)]
-        additional_ipv6_filters = [
-            {"dl_src": mac, "ipv6_src": ip}
-            for mac, ip in allowed_mac_ipv6_pairs]
-        for dl_type, src_port, dst_port, filters_list in (
-                (lib_const.ETHERTYPE_IP, 68, 67, additional_ipv4_filters),
-                (lib_const.ETHERTYPE_IPV6, 546, 547, additional_ipv6_filters)):
-            for additional_filters in filters_list:
-                self._add_flow(
-                    table=ovs_consts.BASE_EGRESS_TABLE,
-                    priority=80,
-                    reg_port=port.ofport,
-                    in_port=port.ofport,
-                    dl_type=dl_type,
-                    **additional_filters,
-                    nw_proto=lib_const.PROTO_NUM_UDP,
-                    tp_src=src_port,
-                    tp_dst=dst_port,
-                    actions='resubmit(,{:d})'.format(
-                        ovs_consts.ACCEPT_OR_INGRESS_TABLE)
-                )
+        for dl_type, src_port, dst_port in (
+                (lib_const.ETHERTYPE_IP, 68, 67),
+                (lib_const.ETHERTYPE_IPV6, 546, 547)):
+            self._add_flow(
+                table=ovs_consts.BASE_EGRESS_TABLE,
+                priority=80,
+                reg_port=port.ofport,
+                in_port=port.ofport,
+                dl_type=dl_type,
+                nw_proto=lib_const.PROTO_NUM_UDP,
+                tp_src=src_port,
+                tp_dst=dst_port,
+                actions='resubmit(,{:d})'.format(
+                    ovs_consts.ACCEPT_OR_INGRESS_TABLE)
+            )
         # Ban dhcp service running on an instance
         for dl_type, src_port, dst_port in (
                 (lib_const.ETHERTYPE_IP, 67, 68),
@@ -1367,18 +1326,6 @@ class OVSFirewallDriver(firewall.FirewallDriver):
             actions='resubmit(,%d)' % ovs_consts.DROPPED_TRAFFIC_TABLE
         )
 
-        # NOTE: The OUTPUT action is used instead of NORMAL action to reduce
-        # cpu utilization, but it causes the datapath rule to be flood rule.
-        # This is due to mac learning not happened on ingress traffic.
-        # While this is ok for no offload case, in ovs offload flood rule
-        # is not offloaded. Therefore, we change the action to be NORMAL in
-        # offload case. In case the explicitly_egress_direct is used the
-        # pipeline don't contain action NORMAL so we don't have flood rule
-        # issue.
-        actions = 'output:{:d}'.format(port.ofport)
-        if (self.int_br.br.is_hw_offload_enabled and
-                not cfg.CONF.AGENT.explicitly_egress_direct):
-            actions = 'mod_vlan_vid:{:d},normal'.format(port.vlan_tag)
         # Allow established and related connections
         for state in (ovsfw_consts.OF_STATE_ESTABLISHED_REPLY,
                       ovsfw_consts.OF_STATE_RELATED):
@@ -1389,7 +1336,7 @@ class OVSFirewallDriver(firewall.FirewallDriver):
                 ct_state=state,
                 ct_mark=ovsfw_consts.CT_MARK_NORMAL,
                 ct_zone=port.vlan_tag,
-                actions=actions
+                actions='output:{:d}'.format(port.ofport)
             )
         self._add_flow(
             table=ovs_consts.RULES_INGRESS_TABLE,
@@ -1548,9 +1495,4 @@ class OVSFirewallDriver(firewall.FirewallDriver):
             # the actions field is bogus anyway.
             del flow['actions']
             del flow['priority']
-            # NOTE(hangyang) If cookie is not set then _delete_flows will
-            # use the OVSBridge._default_cookie to filter the flows but that
-            # will not match with the ip flow's cookie so OVS won't actually
-            # delete the flow
-            flow['cookie'] = ovs_lib.COOKIE_ANY
             self._delete_flows(deferred=False, **flow)
