@@ -15,6 +15,7 @@
 
 import glob
 import grp
+from http import client as httplib
 import os
 import pwd
 import shlex
@@ -32,13 +33,11 @@ from oslo_rootwrap import client
 from oslo_utils import encodeutils
 from oslo_utils import excutils
 from oslo_utils import fileutils
-from six.moves import http_client as httplib
 
 from neutron._i18n import _
 from neutron.agent.linux import xenapi_root_helper
 from neutron.common import utils
 from neutron.conf.agent import common as config
-from neutron.privileged.agent.linux import utils as priv_utils
 from neutron import wsgi
 
 
@@ -133,10 +132,12 @@ def execute(cmd, process_input=None, addl_env=None,
         extra_ok_codes = extra_ok_codes or []
         if returncode and returncode not in extra_ok_codes:
             msg = _("Exit code: %(returncode)d; "
+                    "Cmd: %(cmd)s; "
                     "Stdin: %(stdin)s; "
                     "Stdout: %(stdout)s; "
                     "Stderr: %(stderr)s") % {
                         'returncode': returncode,
+                        'cmd': cmd,
                         'stdin': process_input or '',
                         'stdout': _stdout,
                         'stderr': _stderr}
@@ -395,14 +396,6 @@ def is_effective_group(group_id_or_name):
     return group_id_or_name == effective_group_name
 
 
-def delete_if_exists(path, run_as_root=False):
-    """Delete a path, executed as normal user or with elevated privileges"""
-    if run_as_root:
-        priv_utils.delete_if_exists(path)
-    else:
-        fileutils.delete_if_exists(path)
-
-
 class UnixDomainHTTPConnection(httplib.HTTPConnection):
     """Connection class for HTTP over UNIX domain socket."""
     def __init__(self, host, port=None, strict=None, timeout=None,
