@@ -12,7 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from oslo_log import log
 from ovs.db import idl
 from ovsdbapp.backend.ovs_idl import connection
 from ovsdbapp.backend.ovs_idl import idlutils
@@ -24,9 +23,6 @@ from neutron.plugins.ml2.drivers.ovn.mech_driver.ovsdb import impl_idl_ovn
 from neutron.plugins.ml2.drivers.ovn.mech_driver.ovsdb import ovsdb_monitor
 
 
-LOG = log.getLogger(__name__)
-
-
 class MetadataAgentOvnSbIdl(ovsdb_monitor.OvnIdl):
 
     SCHEMA = 'OVN_Southbound'
@@ -43,9 +39,9 @@ class MetadataAgentOvnSbIdl(ovsdb_monitor.OvnIdl):
         super(MetadataAgentOvnSbIdl, self).__init__(
             None, connection_string, helper)
         if chassis:
-            for table in set(tables).intersection({'Chassis',
-                                                   'Chassis_Private'}):
-                self.tables[table].condition = [['name', '==', chassis]]
+            table = ('Chassis_Private' if 'Chassis_Private' in tables
+                     else 'Chassis')
+            self.tables[table].condition = [['name', '==', chassis]]
         if events:
             self.notify_handler.watch_events(events)
 
@@ -55,12 +51,7 @@ class MetadataAgentOvnSbIdl(ovsdb_monitor.OvnIdl):
     def _get_ovsdb_helper(self, connection_string):
         return idlutils.get_schema_helper(connection_string, self.SCHEMA)
 
-    @tenacity.retry(
-        wait=tenacity.wait_exponential(
-            max=config.get_ovn_ovsdb_retry_max_interval()),
-        reraise=True)
     def start(self):
-        LOG.info('Getting OvsdbSbOvnIdl for MetadataAgent with retry')
         conn = connection.Connection(
             self, timeout=config.get_ovn_ovsdb_timeout())
         return impl_idl_ovn.OvsdbSbOvnIdl(conn)
@@ -75,9 +66,9 @@ class MetadataAgentOvsIdl(object):
         tables = ('Open_vSwitch', 'Bridge', 'Port', 'Interface')
         for table in tables:
             helper.register_table(table)
-        ovs_idl = idl.Idl(
-            connection_string, helper,
-            probe_interval=config.get_ovn_ovsdb_probe_interval())
+        ovs_idl = idl.Idl(connection_string, helper)
+        ovs_idl._session.reconnect.set_probe_interval(
+            config.get_ovn_ovsdb_probe_interval())
         conn = connection.Connection(
             ovs_idl, timeout=config.cfg.CONF.ovs.ovsdb_connection_timeout)
         return idl_ovs.OvsdbIdl(conn)
