@@ -27,7 +27,6 @@ from neutron import opts as neutron_options
 from neutron.plugins.ml2.drivers.ovn.mech_driver import mech_driver
 from neutron.plugins.ml2.drivers.ovn.mech_driver.ovsdb import impl_idl_ovn
 from neutron.plugins.ml2.drivers.ovn.mech_driver.ovsdb import ovn_db_sync
-from neutron.plugins.ml2.drivers.ovn.mech_driver.ovsdb import worker
 from neutron.plugins.ml2 import plugin as ml2_plugin
 
 LOG = logging.getLogger(__name__)
@@ -56,6 +55,14 @@ class OVNMechanismDriver(mech_driver.OVNMechanismDriver):
     def ovn_client(self):
         return self._ovn_client
 
+    def _clean_hash_ring(self):
+        """Don't clean the hash ring.
+
+        If this method was not overriden, cleanup would be performed when
+        calling the db sync and running neutron server would lose all the nodes
+        from the ring.
+        """
+
     # Since we are not using the ovn mechanism driver while syncing,
     # we override the post and pre commit methods so that original ones are
     # not called.
@@ -184,20 +191,23 @@ def main():
         cfg.CONF.set_override('mechanism_drivers', ['ovn-sync'], 'ml2')
         conf.service_plugins = [
             'neutron.services.ovn_l3.plugin.OVNL3RouterPlugin',
-            'neutron.services.segments.plugin.Plugin']
+            'neutron.services.segments.plugin.Plugin',
+            'port_forwarding',
+        ]
     else:
         LOG.error('Invalid core plugin : ["%s"].', cfg.CONF.core_plugin)
         return
 
-    mech_worker = worker.MaintenanceWorker
     try:
-        ovn_api = impl_idl_ovn.OvsdbNbOvnIdl.from_worker(mech_worker)
+        conn = impl_idl_ovn.get_connection(impl_idl_ovn.OvsdbNbOvnIdl)
+        ovn_api = impl_idl_ovn.OvsdbNbOvnIdl(conn)
     except RuntimeError:
         LOG.error('Invalid --ovn-ovn_nb_connection parameter provided.')
         return
 
     try:
-        ovn_sb_api = impl_idl_ovn.OvsdbSbOvnIdl.from_worker(mech_worker)
+        sb_conn = impl_idl_ovn.get_connection(impl_idl_ovn.OvsdbSbOvnIdl)
+        ovn_sb_api = impl_idl_ovn.OvsdbSbOvnIdl(sb_conn)
     except RuntimeError:
         LOG.error('Invalid --ovn-ovn_sb_connection parameter provided.')
         return
