@@ -21,7 +21,6 @@ import tempfile
 import netaddr
 from neutron_lib import constants as n_consts
 from neutron_lib import exceptions
-from neutron_lib.utils import helpers
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import uuidutils
@@ -34,11 +33,11 @@ from neutron.agent.linux import external_process
 from neutron.agent.linux import ip_lib
 from neutron.agent.linux import keepalived
 from neutron.agent.linux import utils as agent_utils
-from neutron.cmd import runtime_checks
 from neutron.common import utils as common_utils
 from neutron.conf.agent.l3 import config as l3_config
 from neutron.plugins.ml2.drivers.openvswitch.agent.common \
     import constants as ovs_const
+from neutron.privileged.agent.linux import dhcp as priv_dhcp
 
 LOG = logging.getLogger(__name__)
 
@@ -52,26 +51,16 @@ CONNTRACK_GRE_MODULE = 'nf_conntrack_proto_gre'
 
 
 def ovs_vxlan_supported(from_ip='192.0.2.1', to_ip='192.0.2.2'):
-    br_name = common_utils.get_rand_device_name(prefix='vxlantest-')
-    port_name = common_utils.get_rand_device_name(prefix='vxlantest-')
-    with ovs_lib.OVSBridge(br_name) as br:
-        port = br.add_tunnel_port(
-            port_name=port_name,
-            remote_ip=from_ip,
-            local_ip=to_ip,
-            tunnel_type=n_consts.TYPE_VXLAN)
+    name = common_utils.get_rand_device_name(prefix='vxlantest-')
+    with ovs_lib.OVSBridge(name) as br:
+        port = br.add_tunnel_port(from_ip, to_ip, n_consts.TYPE_VXLAN)
         return port != ovs_lib.INVALID_OFPORT
 
 
 def ovs_geneve_supported(from_ip='192.0.2.3', to_ip='192.0.2.4'):
-    br_name = common_utils.get_rand_device_name(prefix='genevetest-')
-    port_name = common_utils.get_rand_device_name(prefix='genevetest-')
-    with ovs_lib.OVSBridge(br_name) as br:
-        port = br.add_tunnel_port(
-            port_name=port_name,
-            remote_ip=from_ip,
-            local_ip=to_ip,
-            tunnel_type=n_consts.TYPE_GENEVE)
+    name = common_utils.get_rand_device_name(prefix='genevetest-')
+    with ovs_lib.OVSBridge(name) as br:
+        port = br.add_tunnel_port(from_ip, to_ip, n_consts.TYPE_GENEVE)
         return port != ovs_lib.INVALID_OFPORT
 
 
@@ -93,6 +82,7 @@ def patch_supported():
 
 def nova_notify_supported():
     try:
+        # pylint:disable=import-outside-toplevel
         import neutron.notifiers.nova  # noqa since unused
         return True
     except ImportError:
@@ -251,7 +241,7 @@ def ovs_qos_direct_port_supported():
 
 
 def dhcp_release6_supported():
-    return runtime_checks.dhcp_release6_supported()
+    return priv_dhcp.dhcp_release6_supported()
 
 
 def bridge_firewalling_enabled():
@@ -516,36 +506,3 @@ def gre_conntrack_supported():
         return agent_utils.execute(cmd, log_fail_as_error=False)
     except exceptions.ProcessExecutionError:
         return False
-
-
-def min_tx_rate_support():
-    device_mappings = helpers.parse_mappings(
-        cfg.CONF.SRIOV_NIC.physical_device_mappings, unique_keys=False)
-    devices_to_test = set()
-    for devices_in_physnet in device_mappings.values():
-        for device in devices_in_physnet:
-            devices_to_test.add(device)
-
-    # NOTE(ralonsoh): the VF used by default is 0. Each SR-IOV configured
-    # NIC should have configured at least 1 VF.
-    VF_NUM = 0
-    devices_without_support = set()
-    for device in devices_to_test:
-        try:
-            ip_link = ip_lib.IpLinkCommand(device)
-            # NOTE(ralonsoh): to set min_tx_rate, first is needed to set
-            # max_tx_rate and max_tx_rate >= min_tx_rate.
-            vf_config = {'vf': VF_NUM, 'rate': {'min_tx_rate': int(400),
-                                                'max_tx_rate': int(500)}}
-            ip_link.set_vf_feature(vf_config)
-            vf_config = {'vf': VF_NUM, 'rate': {'min_tx_rate': 0,
-                                                'max_tx_rate': 0}}
-            ip_link.set_vf_feature(vf_config)
-        except ip_lib.InvalidArgument:
-            devices_without_support.add(device)
-
-    if devices_without_support:
-        LOG.debug('The following NICs do not support "min_tx_rate": %s',
-                  devices_without_support)
-        return False
-    return True
