@@ -14,7 +14,6 @@ import re
 
 from neutron_lib.api.definitions import portbindings
 from neutron_lib import constants as const
-import six
 
 # TODO(lucasagomes): Remove OVN_SG_NAME_EXT_ID_KEY in the Rocky release
 OVN_SG_NAME_EXT_ID_KEY = 'neutron:security_group_name'
@@ -47,10 +46,10 @@ OVN_DEVICE_OWNER_EXT_ID_KEY = 'neutron:device_owner'
 OVN_LIVENESS_CHECK_EXT_ID_KEY = 'neutron:liveness_check_at'
 METADATA_LIVENESS_CHECK_EXT_ID_KEY = 'neutron:metadata_liveness_check_at'
 OVN_PORT_BINDING_PROFILE = portbindings.PROFILE
-OVN_PORT_BINDING_PROFILE_PARAMS = [{'parent_name': six.string_types,
-                                    'tag': six.integer_types},
-                                   {'vtep-physical-switch': six.string_types,
-                                    'vtep-logical-switch': six.string_types}]
+OVN_PORT_BINDING_PROFILE_PARAMS = [{'parent_name': str,
+                                    'tag': int},
+                                   {'vtep-physical-switch': str,
+                                    'vtep-logical-switch': str}]
 MIGRATING_ATTR = 'migrating_to'
 OVN_ROUTER_PORT_OPTION_KEYS = ['router-port', 'nat-addresses']
 OVN_GATEWAY_CHASSIS_KEY = 'redirect-chassis'
@@ -160,7 +159,7 @@ SUPPORTED_DHCP_OPTS_MAPPING = {
     6: {'server-id': 'server_id',
         'dns-server': 'dns_server',
         'domain-search': 'domain_search',
-        'ia-addr': 'ia_addr',
+        'ia-addr': 'ip_addr',
         '2': 'server_id',
         '5': 'ia_addr',
         '24': 'domain_search',
@@ -175,7 +174,7 @@ DHCPV6_STATELESS_OPT = 'dhcpv6_stateless'
 # When setting global DHCP options, these options will be ignored
 # as they are required for basic network functions and will be
 # set by Neutron.
-GLOBAL_DHCP_OPTS_BLACKLIST = {
+GLOBAL_DHCP_OPTS_PROHIBIT_LIST = {
     4: ['server_id', 'lease_time', 'mtu', 'router', 'server_mac',
         'dns_server', 'classless_static_route'],
     6: ['dhcpv6_stateless', 'dns_server', 'server_id']}
@@ -275,20 +274,10 @@ LSP_TYPE_VIRTUAL = 'virtual'
 LSP_TYPE_EXTERNAL = 'external'
 LSP_OPTIONS_VIRTUAL_PARENTS_KEY = 'virtual-parents'
 LSP_OPTIONS_VIRTUAL_IP_KEY = 'virtual-ip'
-LSP_OPTIONS_MCAST_FLOOD_REPORTS = 'mcast_flood_reports'
-LSP_OPTIONS_MCAST_FLOOD = 'mcast_flood'
 
 HA_CHASSIS_GROUP_DEFAULT_NAME = 'default_ha_chassis_group'
 HA_CHASSIS_GROUP_HIGHEST_PRIORITY = 32767
 
-# TODO(lucasagomes): Move this to neutron-lib later.
-# Metadata constants
-METADATA_DEFAULT_PREFIX = 16
-METADATA_DEFAULT_IP = '169.254.169.254'
-METADATA_DEFAULT_CIDR = '%s/%d' % (METADATA_DEFAULT_IP,
-                                   METADATA_DEFAULT_PREFIX)
-METADATA_PORT = 80
-
 # OVN igmp options
 MCAST_SNOOP = 'mcast_snoop'
 MCAST_FLOOD_UNREGISTERED = 'mcast_flood_unregistered'
