@@ -35,6 +35,7 @@ from oslo_utils import strutils
 from ovs.db import idl
 from ovsdbapp.backend.ovs_idl import connection
 from ovsdbapp.backend.ovs_idl import idlutils
+from ovsdbapp import constants as ovsdbapp_const
 
 from neutron._i18n import _
 from neutron.common.ovn import constants
@@ -360,7 +361,8 @@ def sort_ips_by_version(addresses):
 
 
 def is_lsp_router_port(port):
-    return port.get('device_owner') in const.ROUTER_PORT_OWNERS
+    return port.get('device_owner') in [const.DEVICE_OWNER_ROUTER_INTF,
+                                        const.DEVICE_OWNER_ROUTER_GW]
 
 
 def get_lrouter_ext_gw_static_route(ovn_router):
@@ -419,7 +421,7 @@ def get_system_dns_resolvers(resolver_file=DNS_RESOLVER_FILE):
 
 
 def get_port_subnet_ids(port):
-    fixed_ips = [ip for ip in port['fixed_ips']]
+    fixed_ips = list(port['fixed_ips'])
     return [f['subnet_id'] for f in fixed_ips]
 
 
@@ -471,7 +473,7 @@ def is_gateway_chassis_invalid(chassis_name, gw_chassis,
 
 
 def is_provider_network(network):
-    return network.get(external_net.EXTERNAL, False)
+    return external_net.EXTERNAL in network
 
 
 def is_neutron_dhcp_agent_port(port):
@@ -546,25 +548,20 @@ def get_chassis_availability_zones(chassis):
     return azs
 
 
-def get_network_name_from_datapath(datapath):
-    return datapath.external_ids['name'].replace('neutron-', '')
-
-
-def connection_config_to_target_string(connection_config):
-    """Converts the Neutron NB/SB connection parameter to the OVN target string
-
-    :param connection_config: Neutron OVN config parameter for the OVN NB or SB
-                              database. See "ovn_sb_connection" or
-                              "ovn_nb_connection" params.
-    :returns: (String) OVN NB/SB ``connection.target`` column value.
-    """
-    regex = re.compile(r'^(?P<proto>\w+)\:((?P<ip>.+)\:(?P<port>\d+)|'
-                       r'(?P<file>[\w\/\.]+))')
-    m = regex.match(connection_config)
-    if m:
-        _dict = m.groupdict()
-        if _dict['ip'] and _dict['port']:
-            return ('p' + _dict['proto'] + ':' + _dict['port'] + ':' +
-                    _dict['ip'])
-        elif _dict['file']:
-            return 'p' + _dict['proto'] + ':' + _dict['file']
+def parse_ovn_lb_port_forwarding(ovn_rtr_lb_pfs):
+    """Return a dictionary compatible with port forwarding from OVN lb."""
+    result = {}
+    for ovn_lb in ovn_rtr_lb_pfs:
+        ext_ids = ovn_lb.external_ids
+        fip_id = ext_ids.get(constants.OVN_FIP_EXT_ID_KEY)
+        protocol = (ovn_lb.protocol[0]
+                    if ovn_lb.protocol else ovsdbapp_const.PROTO_TCP)
+        fip_dict = result.get(fip_id, {})
+        fip_dict_proto = fip_dict.get(protocol, set())
+        ovn_vips = ovn_lb.vips
+        for vip, ips in ovn_vips.items():
+            for ip in ips.split(','):
+                fip_dict_proto.add("{} {}".format(vip, ip))
+        fip_dict[protocol] = fip_dict_proto
+        result[fip_id] = fip_dict
+    return result
