@@ -38,7 +38,6 @@ import oslo_messaging
 from oslo_serialization import jsonutils
 from oslo_utils import importutils
 from oslo_utils import timeutils
-import six
 
 from neutron.agent.common import utils
 from neutron.api.rpc.callbacks import version_manager
@@ -125,7 +124,7 @@ class AgentAvailabilityZoneMixin(az_ext.AvailabilityZonePluginBase):
 
     def _adjust_az_filters(self, filters):
         # The intersect of sets gets us applicable filter keys (others ignored)
-        common_keys = six.viewkeys(filters) & six.viewkeys(AZ_ATTRIBUTE_MAP)
+        common_keys = filters.keys() & AZ_ATTRIBUTE_MAP.keys()
         for key in common_keys:
             filter_key = AZ_ATTRIBUTE_MAP[key]['agent_key']
             filter_vals = filters.pop(key)
@@ -270,9 +269,6 @@ class AgentDbMixin(ext_agent.AgentPluginBase, AgentAvailabilityZoneMixin):
                          payload=events.DBEventPayload(
                              context, states=(agent,), resource_id=id))
         agent.delete()
-        registry.publish(resources.AGENT, events.AFTER_DELETE, self,
-                         payload=events.DBEventPayload(
-                             context, states=(agent,), resource_id=id))
 
     @db_api.retry_if_session_inactive()
     def update_agent(self, context, id, agent):
@@ -434,7 +430,6 @@ class AgentDbMixin(ext_agent.AgentPluginBase, AgentAvailabilityZoneMixin):
 
         agent_state['agent_status'] = status
         agent_state['admin_state_up'] = agent.admin_state_up
-        agent_state['id'] = agent.id
         registry.publish(resources.AGENT, event_type, self,
                          payload=events.DBEventPayload(
                              context=context, metadata={
