@@ -16,7 +16,6 @@
 import functools
 
 import netaddr
-from neutron_lib.api.definitions import external_net as extnet_def
 from neutron_lib.api.definitions import ip_allocation as ipalloc_apidef
 from neutron_lib.api.definitions import portbindings as portbindings_def
 from neutron_lib.api.definitions import subnetpool as subnetpool_def
@@ -159,6 +158,7 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
                 cfg.CONF.notify_nova_on_port_data_changes):
             # Import nova conditionally to support the use case of Neutron
             # being used outside of an OpenStack context.
+            # pylint: disable=import-outside-toplevel
             from neutron.notifiers import nova
             self.nova_notifier = nova.Notifier.get_instance()
             # NOTE(arosen) These event listeners are here to hook into when
@@ -173,6 +173,7 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
                     self.nova_notifier.record_port_status_changed)
         if cfg.CONF.ironic.enable_notifications:
             # Import ironic notifier conditionally
+            # pylint: disable=import-outside-toplevel
             from neutron.notifiers import ironic
             self.ironic_notifier = ironic.Notifier.get_instance()
 
@@ -417,12 +418,10 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
         return network
 
     @db_api.retry_if_session_inactive()
-    def update_network(self, context, id, network, db_network=None):
+    def update_network(self, context, id, network):
         n = network['network']
-        # we dont't use DB objects not belonging to the current active session
-        db_network = db_network if context.session.is_active else None
         with db_api.CONTEXT_WRITER.using(context):
-            network = db_network or self._get_network(context, id)
+            network = self._get_network(context, id)
             # validate 'shared' parameter
             if 'shared' in n:
                 entry = None
@@ -505,8 +504,7 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
                 network_db = self._get_network(context, id)
                 network = self._make_network_dict(network_db, context=context)
                 registry.notify(resources.NETWORK, events.PRECOMMIT_DELETE,
-                                self, context=context, network_id=id,
-                                network=network)
+                                self, context=context, network_id=id)
                 # We expire network_db here because precommit deletion
                 # might have left the relationship stale, for example,
                 # if we deleted a segment.
@@ -604,11 +602,11 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
                 error_message = _("Multicast IP subnet is not supported "
                                   "if enable_dhcp is True")
                 raise exc.InvalidInput(error_message=error_message)
-            elif net.is_loopback():
+            if net.is_loopback():
                 error_message = _("Loopback IP subnet is not supported "
                                   "if enable_dhcp is True")
                 raise exc.InvalidInput(error_message=error_message)
-            elif ip_ver == constants.IP_VERSION_4 and net.first == 0:
+            if ip_ver == constants.IP_VERSION_4 and net.first == 0:
                 error_message = _("First IP '0.0.0.0' of network is not "
                                   "supported if enable_dhcp is True.")
                 raise exc.InvalidInput(error_message=error_message)
@@ -738,12 +736,11 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
     @db_api.retry_if_session_inactive()
     def _create_subnet_postcommit(self, context, result,
                                   network=None, ipam_subnet=None):
-        # need to get db net obj with full subnet info either if no network
-        # is passed or if passed network is an external net dict from
-        # ml2 plugin (with only IDs in 'subnets')
-        if not network or network.get(extnet_def.EXTERNAL):
+        if not network:
             network = self._get_network(context,
                                         result['network_id'])
+        if not ipam_subnet:
+            ipam_subnet = self.ipam.get_subnet(context, result['id'])
 
         if hasattr(network, 'external') and network.external:
             self._update_router_gw_ports(context,
@@ -752,8 +749,6 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
         # If this subnet supports auto-addressing, then update any
         # internal ports on the network with addresses for this subnet.
         if ipv6_utils.is_auto_address_subnet(result):
-            if not ipam_subnet:
-                ipam_subnet = self.ipam.get_subnet(context, result['id'])
             updated_ports = self.ipam.add_auto_addrs_on_network_ports(
                 context, result, ipam_subnet)
             for port_id in updated_ports:
@@ -946,8 +941,8 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
                         self, **kwargs)
 
         with db_api.CONTEXT_WRITER.using(context):
-            subnet, changes = self.ipam.update_db_subnet(
-                context, id, s, db_pools, subnet_obj=subnet_obj)
+            subnet, changes = self.ipam.update_db_subnet(context, id, s,
+                                                         db_pools)
         return self._make_subnet_dict(subnet, context=context), orig
 
     @property
@@ -1058,8 +1053,7 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
         with db_api.exc_to_retry(sql_exc.IntegrityError), \
                 db_api.CONTEXT_WRITER.using(context):
             registry.notify(resources.SUBNET, events.PRECOMMIT_DELETE,
-                            self, context=context, subnet_id=subnet.id,
-                            subnet_obj=subnet)
+                            self, context=context, subnet_id=subnet.id)
             subnet.delete()
             # Delete related ipam subnet manually,
             # since there is no FK relationship
@@ -1317,7 +1311,7 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
         if not validators.is_attr_set(network_id):
             msg = _("network_id must be specified.")
             raise exc.InvalidInput(error_message=msg)
-        if not self._network_exists(context, network_id):
+        if not network_obj.Network.objects_exist(context, id=network_id):
             raise exc.NetworkNotFound(net_id=network_id)
 
         subnetpool = subnetpool_obj.SubnetPool.get_object(context,
@@ -1427,8 +1421,7 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
             port_data['mac_address'] = p.get('mac_address')
         with db_api.CONTEXT_WRITER.using(context):
             # Ensure that the network exists.
-            if not self._network_exists(context, network_id):
-                raise exc.NetworkNotFound(net_id=network_id)
+            self._get_network(context, network_id)
 
             # Create the port
             db_port = self._create_db_port_obj(context, port_data)
@@ -1466,13 +1459,11 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
                                         new_mac, current_owner)
 
     @db_api.retry_if_session_inactive()
-    def update_port(self, context, id, port, db_port=None):
-        # we dont't use DB objects not belonging to the current active session
-        db_port = db_port if context.session.is_active else None
+    def update_port(self, context, id, port):
         new_port = port['port']
 
         with db_api.CONTEXT_WRITER.using(context):
-            db_port = db_port or self._get_port(context, id)
+            db_port = self._get_port(context, id)
             new_mac = new_port.get('mac_address')
             self._validate_port_for_update(context, db_port, new_port, new_mac)
             # Note: _make_port_dict is called here to load extension data
@@ -1572,9 +1563,7 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
                                       sorts=sorts, limit=limit,
                                       marker_obj=marker_obj,
                                       page_reverse=page_reverse)
-        items = [self._make_port_dict(c, fields, bulk=True) for c in query]
-        # TODO(obondarev): use neutron_lib constant
-        resource_extend.apply_funcs('ports_bulk', items, None)
+        items = [self._make_port_dict(c, fields) for c in query]
         if limit and page_reverse:
             items.reverse()
         return items
@@ -1649,7 +1638,7 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
                 return {'prefixes': subnetpool.prefixes}
 
             all_prefix_set = netaddr.IPSet(subnetpool.prefixes)
-            removal_prefix_set = netaddr.IPSet([x for x in prefixes])
+            removal_prefix_set = netaddr.IPSet(list(prefixes))
             if all_prefix_set.isdisjoint(removal_prefix_set):
                 # The prefixes requested for removal are not in the prefix
                 # list making this a no-op, so simply return.
