@@ -83,8 +83,7 @@ class IpamBackendMixin(db_base_plugin_common.DbBasePluginCommon):
 
     @staticmethod
     def _is_distributed_service(port):
-        return (port.get('device_owner') == const.DEVICE_OWNER_DHCP and
-                port.get('device_id').startswith('ovn'))
+        return port.get('device_owner') == const.DEVICE_OWNER_DISTRIBUTED
 
     def delete_subnet(self, context, subnet_id):
         pass
@@ -200,8 +199,7 @@ class IpamBackendMixin(db_base_plugin_common.DbBasePluginCommon):
             new_type.create()
         return updated_types
 
-    def update_db_subnet(self, context, subnet_id, s, oldpools,
-            subnet_obj=None):
+    def update_db_subnet(self, context, subnet_id, s, oldpools):
         changes = {}
         if "dns_nameservers" in s:
             changes['dns_nameservers'] = (
@@ -219,7 +217,7 @@ class IpamBackendMixin(db_base_plugin_common.DbBasePluginCommon):
             changes['service_types'] = (
                 self._update_subnet_service_types(context, subnet_id, s))
 
-        subnet_obj = subnet_obj or self._get_subnet_object(context, subnet_id)
+        subnet_obj = self._get_subnet_object(context, subnet_id)
         subnet_obj.update_fields(s)
         subnet_obj.update()
         return subnet_obj, changes
@@ -242,14 +240,14 @@ class IpamBackendMixin(db_base_plugin_common.DbBasePluginCommon):
             if cidr.prefixlen == 0:
                 err_msg = _("0 is not allowed as CIDR prefix length")
                 raise exc.InvalidInput(error_message=err_msg)
-
         if cfg.CONF.allow_overlapping_ips:
-            subnet_list = network.subnets
+            subnet_list = [{'id': s.id, 'cidr': s.cidr}
+                           for s in network.subnets]
         else:
-            subnet_list = self._get_subnets(context)
+            subnet_list = subnet_obj.Subnet.get_subnet_cidrs(context)
         for subnet in subnet_list:
-            if ((netaddr.IPSet([subnet.cidr]) & new_subnet_ipset) and
-                    str(subnet.cidr) != const.PROVISIONAL_IPV6_PD_PREFIX):
+            if ((netaddr.IPSet([subnet['cidr']]) & new_subnet_ipset) and
+                    str(subnet['cidr']) != const.PROVISIONAL_IPV6_PD_PREFIX):
                 # don't give out details of the overlapping subnet
                 err_msg = ("Requested subnet with cidr: %(cidr)s for "
                            "network: %(network_id)s overlaps with another "
@@ -260,8 +258,8 @@ class IpamBackendMixin(db_base_plugin_common.DbBasePluginCommon):
                          "overlaps with subnet %(subnet_id)s "
                          "(CIDR: %(cidr)s)",
                          {'new_cidr': new_subnet_cidr,
-                          'subnet_id': subnet.id,
-                          'cidr': subnet.cidr})
+                          'subnet_id': subnet['id'],
+                          'cidr': subnet['cidr']})
                 raise exc.InvalidInput(error_message=err_msg)
 
     def _validate_network_subnetpools(self, network, subnet_ip_version,
@@ -389,7 +387,7 @@ class IpamBackendMixin(db_base_plugin_common.DbBasePluginCommon):
             if segment.is_dynamic:
                 raise segment_exc.SubnetCantAssociateToDynamicSegment()
 
-    def _get_subnet_for_fixed_ip(self, context, fixed, subnets):
+    def _get_subnet_for_fixed_ip(self, context, fixed, subnets, network_id):
         # Subnets are all the subnets belonging to the same network.
         if not subnets:
             msg = _('IP allocation requires subnets for network')
@@ -402,12 +400,13 @@ class IpamBackendMixin(db_base_plugin_common.DbBasePluginCommon):
                         return subnet
             subnet = get_matching_subnet()
             if not subnet:
-                subnet_obj = self._get_subnet_object(context,
-                                                     fixed['subnet_id'])
+                # Call this method to keep original status code
+                # in case subnet is not found
+                self._get_subnet_object(context, fixed['subnet_id'])
                 msg = (_("Failed to create port on network %(network_id)s"
                          ", because fixed_ips included invalid subnet "
                          "%(subnet_id)s") %
-                       {'network_id': subnet_obj.network_id,
+                       {'network_id': network_id,
                         'subnet_id': fixed['subnet_id']})
                 raise exc.InvalidInput(error_message=msg)
             # Ensure that the IP is valid on the subnet
