@@ -293,7 +293,8 @@ class IpamPluggableBackend(ipam_backend_mixin.IpamBackendMixin):
         fixed_ip_list = []
         for fixed in fixed_ips:
             fixed['device_owner'] = device_owner
-            subnet = self._get_subnet_for_fixed_ip(context, fixed, subnets)
+            subnet = self._get_subnet_for_fixed_ip(context, fixed,
+                                                   subnets, network_id)
 
             is_auto_addr_subnet = ipv6_utils.is_auto_address_subnet(subnet)
             if ('ip_address' in fixed and
@@ -494,8 +495,8 @@ class IpamPluggableBackend(ipam_backend_mixin.IpamBackendMixin):
         self._ipam_deallocate_ips(context, ipam_driver, port,
                                   port['fixed_ips'])
 
-    def update_db_subnet(self, context, id, s, old_pools, subnet_obj=None):
-        subnet = subnet_obj or obj_subnet.Subnet.get_object(context, id=id)
+    def update_db_subnet(self, context, id, s, old_pools):
+        subnet = obj_subnet.Subnet.get_object(context, id=id)
         old_segment_id = subnet.segment_id if subnet else None
         if 'segment_id' in s:
             self._validate_segment(
@@ -506,7 +507,7 @@ class IpamPluggableBackend(ipam_backend_mixin.IpamBackendMixin):
         # so create unchanged copy for ipam driver
         subnet_copy = copy.deepcopy(s)
         subnet, changes = super(IpamPluggableBackend, self).update_db_subnet(
-            context, id, s, old_pools, subnet_obj=subnet_obj)
+            context, id, s, old_pools)
         ipam_driver = driver.Pool.get_instance(None, context)
 
         # Set old allocation pools if no new pools are provided by user.
@@ -545,8 +546,7 @@ class IpamPluggableBackend(ipam_backend_mixin.IpamBackendMixin):
                     p.get(portbindings.HOST_ID),
                     p.get('device_owner'),
                     fixed_configured,
-                    p.get('fixed_ips'),
-                    distributed_service=self._is_distributed_service(p))
+                    p.get('fixed_ips'))
                 if subnet['id'] not in [s['id'] for s in subnet_candidates]:
                     continue
 
