@@ -427,7 +427,8 @@ class L3_NAT_dbonly_mixin(l3.RouterPluginBase,
 
             self._check_for_dup_router_subnets(context, router,
                                                new_network_id,
-                                               subnets)
+                                               subnets,
+                                               include_gateway=True)
             self._create_router_gw_port(context, router,
                                         new_network_id, ext_ips)
 
@@ -552,7 +553,8 @@ class L3_NAT_dbonly_mixin(l3.RouterPluginBase,
                                                 filters=filters)
 
     def _check_for_dup_router_subnets(self, context, router,
-                                      network_id, new_subnets):
+                                      network_id, new_subnets,
+                                      include_gateway=False):
         # It's possible these ports are on the same network, but
         # different subnets.
         new_subnet_ids = {s['id'] for s in new_subnets}
@@ -563,13 +565,8 @@ class L3_NAT_dbonly_mixin(l3.RouterPluginBase,
                     msg = (_("Router already has a port on subnet %s")
                            % ip['subnet_id'])
                     raise n_exc.BadRequest(resource='router', msg=msg)
-                if p.get('device_owner') == DEVICE_OWNER_ROUTER_GW:
-                    ext_subts = self._core_plugin.get_subnets(
-                        context.elevated(),
-                        filters={'network_id': [p['network_id']]})
-                    for sub in ext_subts:
-                        router_subnets.append(sub['id'])
-                else:
+                gw_owner = (p.get('device_owner') == DEVICE_OWNER_ROUTER_GW)
+                if include_gateway == gw_owner:
                     router_subnets.append(ip['subnet_id'])
 
         # Ignore temporary Prefix Delegation CIDRs
@@ -640,7 +637,7 @@ class L3_NAT_dbonly_mixin(l3.RouterPluginBase,
             msg = _('Router port must have at least one fixed IP')
             raise n_exc.BadRequest(resource='router', msg=msg)
 
-        fixed_ips = [ip for ip in port['fixed_ips']]
+        fixed_ips = list(port['fixed_ips'])
         for fixed_ip in fixed_ips:
             subnet = self._core_plugin.get_subnet(
                 context, fixed_ip['subnet_id'])
@@ -687,7 +684,7 @@ class L3_NAT_dbonly_mixin(l3.RouterPluginBase,
                             'p': existing_port['id'],
                             'nid': existing_port['network_id']})
 
-            fixed_ips = [ip for ip in port['fixed_ips']]
+            fixed_ips = list(port['fixed_ips'])
             subnets = []
             for fixed_ip in fixed_ips:
                 subnet = self._core_plugin.get_subnet(context,
@@ -1264,9 +1261,8 @@ class L3_NAT_dbonly_mixin(l3.RouterPluginBase,
                 'context': context,
                 'association_event': association_event}
 
-    def _is_ipv4_network(self, context, net_id):
-        net = self._core_plugin._get_network(context, net_id)
-        return any(s.ip_version == 4 for s in net.subnets)
+    def _is_ipv4_network(self, context, net_db):
+        return any(s.ip_version == 4 for s in net_db.subnets)
 
     def _create_floatingip(self, context, floatingip,
                            initial_status=constants.FLOATINGIP_STATUS_ACTIVE):
@@ -1282,11 +1278,12 @@ class L3_NAT_dbonly_mixin(l3.RouterPluginBase,
         fip_id = uuidutils.generate_uuid()
 
         f_net_id = fip['floating_network_id']
-        if not self._core_plugin._network_is_external(context, f_net_id):
+        f_net_db = self._core_plugin._get_network(context, f_net_id)
+        if not f_net_db.external:
             msg = _("Network %s is not a valid external network") % f_net_id
             raise n_exc.BadRequest(resource='floatingip', msg=msg)
 
-        if not self._is_ipv4_network(context, f_net_id):
+        if not self._is_ipv4_network(context, f_net_db):
             msg = _("Network %s does not contain any IPv4 subnet") % f_net_id
             raise n_exc.BadRequest(resource='floatingip', msg=msg)
 
@@ -1519,24 +1516,18 @@ class L3_NAT_dbonly_mixin(l3.RouterPluginBase,
 
     @db_api.retry_if_session_inactive()
     def delete_disassociated_floatingips(self, context, network_id):
-        fip_ids = l3_obj.FloatingIP.get_disassociated_ids_for_net(
-            context, network_id)
+        fip_objs = l3_obj.FloatingIP.get_objects(
+            context,
+            floating_network_id=network_id, router_id=None, fixed_port_id=None)
 
-        for fip_id in fip_ids:
-            self.delete_floatingip(context, fip_id)
+        for fip in fip_objs:
+            self.delete_floatingip(context, fip.id)
 
     @db_api.retry_if_session_inactive()
     def get_floatingips_count(self, context, filters=None):
         filters = filters or {}
         return l3_obj.FloatingIP.count(context, **filters)
 
-    def _router_exists(self, context, router_id):
-        try:
-            self.get_router(context.elevated(), router_id)
-            return True
-        except l3_exc.RouterNotFound:
-            return False
-
     def prevent_l3_port_deletion(self, context, port_id):
         """Checks to make sure a port is allowed to be deleted.
 
@@ -1574,7 +1565,8 @@ class L3_NAT_dbonly_mixin(l3.RouterPluginBase,
                           "%(port_id)s no longer exists, allowing deletion.",
                           {'f_id': port['device_id'], 'port_id': port['id']})
                 return
-        elif not self._router_exists(context, port['device_id']):
+        elif not l3_obj.Router.objects_exist(context.elevated(),
+                                             id=port['device_id']):
             LOG.debug("Router %(router_id)s corresponding to port "
                       "%(port_id)s no longer exists, allowing deletion.",
                       {'router_id': port['device_id'],
