@@ -13,8 +13,6 @@
 #    under the License.
 import collections
 
-import netaddr
-from neutron_lib.api.definitions import external_net as extnet_apidef
 from neutron_lib.api.definitions import l3 as l3_apidef
 from neutron_lib.api.definitions import portbindings
 from neutron_lib.api.definitions import portbindings_extended
@@ -37,7 +35,6 @@ from oslo_config import cfg
 from oslo_log import helpers as log_helper
 from oslo_log import log as logging
 from oslo_utils import excutils
-import six
 
 from neutron._i18n import _
 from neutron.api import extensions
@@ -51,9 +48,7 @@ from neutron.db import models_v2
 from neutron.extensions import _admin_state_down_before_update_lib
 from neutron.ipam import utils as ipam_utils
 from neutron.objects import agent as ag_obj
-from neutron.objects import base as base_obj
 from neutron.objects import l3agent as rb_obj
-from neutron.objects import ports as port_obj
 from neutron.objects import router as l3_obj
 
 
@@ -414,15 +409,6 @@ class DVRResourceOperationHandler(object):
                 if host_id:
                     return
 
-    @registry.receives(resources.NETWORK, [events.AFTER_DELETE])
-    def delete_fip_namespaces_for_ext_net(self, rtype, event, trigger,
-                                          context, network, **kwargs):
-        if network.get(extnet_apidef.EXTERNAL):
-            # Send the information to all the L3 Agent hosts
-            # to clean up the fip namespace as it is no longer required.
-            self.l3plugin.l3_rpc_notifier.delete_fipnamespace_for_ext_net(
-                context, network['id'])
-
     def _get_ports_for_allowed_address_pair_ip(self, context, network_id,
                                                fixed_ip):
         """Return all active ports associated with the allowed_addr_pair ip."""
@@ -483,17 +469,6 @@ class DVRResourceOperationHandler(object):
                                 fixed_ip_address))
                         if not addr_pair_active_service_port_list:
                             return
-                        self._inherit_service_port_and_arp_update(
-                            context, addr_pair_active_service_port_list[0])
-
-    def _inherit_service_port_and_arp_update(self, context, service_port):
-        """Function inherits port host bindings for allowed_address_pair."""
-        service_port_dict = self.l3plugin._core_plugin._make_port_dict(
-            service_port)
-        address_pair_list = service_port_dict.get('allowed_address_pairs')
-        for address_pair in address_pair_list:
-            self.update_arp_entry_for_dvr_service_port(context,
-                                                       service_port_dict)
 
     @registry.receives(resources.ROUTER_INTERFACE, [events.BEFORE_CREATE])
     @db_api.retry_if_session_inactive()
@@ -770,61 +745,6 @@ class DVRResourceOperationHandler(object):
                                                            p['id'],
                                                            l3_port_check=False)
 
-    def _get_ext_nets_by_host(self, context, host):
-        ext_nets = set()
-        ports_ids = port_obj.Port.get_ports_by_host(context, host)
-        for port_id in ports_ids:
-            fips = self._get_floatingips_by_port_id(context, port_id)
-            for fip in fips:
-                ext_nets.add(fip.floating_network_id)
-        return ext_nets
-
-    @registry.receives(resources.AGENT, [events.AFTER_CREATE])
-    def create_fip_agent_gw_ports(self, resource, event,
-                                  trigger, payload=None):
-        """Create floating agent gw ports for DVR L3 agent.
-
-        Create floating IP Agent gateway ports when an L3 agent is created.
-        """
-        if not payload:
-            return
-        agent = payload.latest_state
-        if agent.get('agent_type') != const.AGENT_TYPE_L3:
-            return
-        # NOTE(slaweq) agent is passed in payload as dict so to avoid getting
-        # again from db, lets just get configuration from this dict directly
-        l3_agent_mode = agent.get('configurations', {}).get('agent_mode')
-        if l3_agent_mode not in [const.L3_AGENT_MODE_DVR,
-                                 const.L3_AGENT_MODE_DVR_SNAT]:
-            return
-
-        host = agent['host']
-        context = payload.context.elevated()
-        for ext_net in self._get_ext_nets_by_host(context, host):
-            self.create_fip_agent_gw_port_if_not_exists(
-                context, ext_net, host)
-
-    @registry.receives(resources.AGENT, [events.AFTER_DELETE])
-    def delete_fip_agent_gw_ports(self, resource, event,
-                                  trigger, payload=None):
-        """Delete floating agent gw ports for DVR.
-
-        Delete floating IP Agent gateway ports from host when an L3 agent is
-        deleted.
-        """
-        if not payload:
-            return
-        agent = payload.latest_state
-        if agent.get('agent_type') != const.AGENT_TYPE_L3:
-            return
-        if self._get_agent_mode(agent) not in [const.L3_AGENT_MODE_DVR,
-                                               const.L3_AGENT_MODE_DVR_SNAT]:
-            return
-
-        agent_gw_ports = self._get_agent_gw_ports(payload.context, agent['id'])
-        for gw_port in agent_gw_ports:
-            self._core_plugin.delete_port(payload.context, gw_port['id'])
-
 
 class _DVRAgentInterfaceMixin(object):
     """Contains calls made by the DVR scheduler and RPC interface.
@@ -1101,14 +1021,6 @@ class _DVRAgentInterfaceMixin(object):
         if ports:
             return ports[0]
 
-    def _get_agent_gw_ports(self, context, agent_id):
-        """Return agent gw ports."""
-        filters = {
-            'device_id': [agent_id],
-            'device_owner': [const.DEVICE_OWNER_AGENT_GW]
-        }
-        return self._core_plugin.get_ports(context, filters)
-
     def check_for_fip_and_create_agent_gw_port_on_host_if_not_exists(
             self, context, port, host):
         """Create fip agent_gw_port on host if not exists"""
@@ -1137,8 +1049,6 @@ class _DVRAgentInterfaceMixin(object):
                         {'ag': const.AGENT_TYPE_L3,
                          'host': host})
             return
-        if not l3_agent_db:
-            return
 
         l3_agent_mode = self._get_agent_mode(l3_agent_db)
         if l3_agent_mode == const.L3_AGENT_MODE_DVR_NO_EXTERNAL:
@@ -1194,21 +1104,6 @@ class _DVRAgentInterfaceMixin(object):
         self._populate_mtu_and_subnets_for_ports(context, [agent_port])
         return agent_port
 
-    def _generate_arp_table_and_notify_agent(self, context, fixed_ip,
-                                             mac_address, notifier):
-        """Generates the arp table entry and notifies the l3 agent."""
-        ip_address = fixed_ip['ip_address']
-        subnet = fixed_ip['subnet_id']
-        arp_table = {'ip_address': ip_address,
-                     'mac_address': mac_address,
-                     'subnet_id': subnet}
-        filters = {'fixed_ips': {'subnet_id': [subnet]},
-                   'device_owner': [const.DEVICE_OWNER_DVR_INTERFACE]}
-        ports = self._core_plugin.get_ports(context, filters=filters)
-        routers = [port['device_id'] for port in ports]
-        for router_id in routers:
-            notifier(context, router_id, arp_table)
-
     def _get_subnet_id_for_given_fixed_ip(self, context, fixed_ip, port_dict):
         """Returns the subnet_id that matches the fixedip on a network."""
         filters = {'network_id': [port_dict['network_id']]}
@@ -1217,78 +1112,6 @@ class _DVRAgentInterfaceMixin(object):
             if ipam_utils.check_subnet_ip(subnet['cidr'], fixed_ip):
                 return subnet['id']
 
-    def _get_allowed_address_pair_fixed_ips(self, context, port_dict):
-        """Returns all fixed_ips associated with the allowed_address_pair."""
-        aa_pair_fixed_ips = []
-        if port_dict.get('allowed_address_pairs'):
-            for address_pair in port_dict['allowed_address_pairs']:
-                aap_ip_cidr = address_pair['ip_address'].split("/")
-                if len(aap_ip_cidr) == 1 or int(aap_ip_cidr[1]) == 32:
-                    subnet_id = self._get_subnet_id_for_given_fixed_ip(
-                        context, aap_ip_cidr[0], port_dict)
-                    if subnet_id is not None:
-                        fixed_ip = {'subnet_id': subnet_id,
-                                    'ip_address': aap_ip_cidr[0]}
-                        aa_pair_fixed_ips.append(fixed_ip)
-                    else:
-                        LOG.debug("Subnet does not match for the given "
-                                  "fixed_ip %s for arp update", aap_ip_cidr[0])
-        return aa_pair_fixed_ips
-
-    def update_arp_entry_for_dvr_service_port(self, context, port_dict):
-        """Notify L3 agents of ARP table entry for dvr service port.
-
-        When a dvr service port goes up, look for the DVR router on
-        the port's subnet, and send the ARP details to all
-        L3 agents hosting the router to add it.
-        If there are any allowed_address_pairs associated with the port
-        those fixed_ips should also be updated in the ARP table.
-        """
-        fixed_ips = port_dict['fixed_ips']
-        if not fixed_ips:
-            return
-        allowed_address_pair_fixed_ips = (
-            self._get_allowed_address_pair_fixed_ips(context, port_dict))
-        changed_fixed_ips = fixed_ips + allowed_address_pair_fixed_ips
-        for fixed_ip in changed_fixed_ips:
-            self._generate_arp_table_and_notify_agent(
-                context, fixed_ip, port_dict['mac_address'],
-                self.l3_rpc_notifier.add_arp_entry)
-
-    def delete_arp_entry_for_dvr_service_port(self, context, port_dict,
-                                              fixed_ips_to_delete=None):
-        """Notify L3 agents of ARP table entry for dvr service port.
-
-        When a dvr service port goes down, look for the DVR
-        router on the port's subnet, and send the ARP details to all
-        L3 agents hosting the router to delete it.
-        If there are any allowed_address_pairs associated with the
-        port, those fixed_ips should be removed from the ARP table.
-        """
-        fixed_ips = port_dict['fixed_ips']
-        if not fixed_ips:
-            return
-        if not fixed_ips_to_delete:
-            allowed_address_pair_fixed_ips = (
-                self._get_allowed_address_pair_fixed_ips(context, port_dict))
-            fixed_ips_to_delete = fixed_ips + allowed_address_pair_fixed_ips
-        for fixed_ip in fixed_ips_to_delete:
-            self._generate_arp_table_and_notify_agent(
-                context, fixed_ip, port_dict['mac_address'],
-                self.l3_rpc_notifier.del_arp_entry)
-
-    def _get_address_pair_active_port_with_fip(
-            self, context, port_dict, port_addr_pair_ip):
-        port_valid_state = (port_dict['admin_state_up'] or
-                            port_dict['status'] == const.PORT_STATUS_ACTIVE)
-        if not port_valid_state:
-            return
-        fips = l3_obj.FloatingIP.get_objects(
-            context, _pager=base_obj.Pager(limit=1),
-            fixed_ip_address=netaddr.IPAddress(port_addr_pair_ip))
-        return self._core_plugin.get_port(
-            context, fips[0].fixed_port_id) if fips else None
-
 
 class L3_NAT_with_dvr_db_mixin(_DVRAgentInterfaceMixin,
                                DVRResourceOperationHandler,
@@ -1303,7 +1126,7 @@ class L3_NAT_with_dvr_db_mixin(_DVRAgentInterfaceMixin,
 
     def _get_device_owner(self, context, router=None):
         """Get device_owner for the specified router."""
-        router_is_uuid = isinstance(router, six.string_types)
+        router_is_uuid = isinstance(router, str)
         if router_is_uuid:
             router = self._get_router(context, router)
         if is_distributed_router(router):
@@ -1398,23 +1221,11 @@ class L3_NAT_with_dvr_db_mixin(_DVRAgentInterfaceMixin,
     def get_ports_under_dvr_connected_subnet(self, context, subnet_id):
         query = dvr_mac_db.get_ports_query_by_subnet_and_ip(context, subnet_id)
         ports = [p for p in query.all() if is_port_bound(p)]
-        # TODO(slaweq): if there would be way to pass to neutron-lib only
-        # list of extensions which actually should be processed, than setting
-        # process_extensions=True below could avoid that second loop and
-        # getting allowed_address_pairs for each of the ports
-        ports_list = [
+        return [
             self.l3plugin._core_plugin._make_port_dict(
                 port, process_extensions=False)
             for port in ports
         ]
-        ports_ids = [p['id'] for p in ports_list]
-        allowed_address_pairs = (
-            self._core_plugin.get_allowed_address_pairs_for_ports(
-                context, ports_ids))
-        for port in ports_list:
-            port['allowed_address_pairs'] = allowed_address_pairs.get(
-                port['id'], [])
-        return ports_list
 
 
 def is_distributed_router(router):
