@@ -14,7 +14,6 @@
 
 import netaddr
 from neutron_lib.api.definitions import port as port_def
-from neutron_lib.api import extensions
 from neutron_lib.api import validators
 from neutron_lib.callbacks import events
 from neutron_lib.callbacks import exceptions
@@ -32,7 +31,6 @@ from neutron_lib.utils import helpers
 from neutron_lib.utils import net
 from oslo_log import log as logging
 from oslo_utils import uuidutils
-import six
 from sqlalchemy.orm import scoped_session
 
 from neutron._i18n import _
@@ -169,7 +167,7 @@ class SecurityGroupDbMixin(ext_sg.SecurityGroupPluginBase,
         # GETS. TODO(arosen)  context handling can probably be improved here.
         filters = filters or {}
         if not default_sg and context.tenant_id:
-            tenant_id = filters.get('tenant_id')
+            tenant_id = filters.get('project_id') or filters.get('tenant_id')
             if tenant_id:
                 tenant_id = tenant_id[0]
             else:
@@ -418,7 +416,7 @@ class SecurityGroupDbMixin(ext_sg.SecurityGroupPluginBase,
         protocol = rule_dict.get('protocol')
         if protocol:
             # object expects strings only
-            protocol = six.text_type(protocol)
+            protocol = str(protocol)
 
         args = {
             'id': (rule_dict.get('id') or uuidutils.generate_uuid()),
@@ -517,9 +515,9 @@ class SecurityGroupDbMixin(ext_sg.SecurityGroupPluginBase,
                 ip_proto in const.SG_PORT_PROTO_NAMES):
             if rule['port_range_min'] == 0 or rule['port_range_max'] == 0:
                 raise ext_sg.SecurityGroupInvalidPortValue(port=0)
-            elif (rule['port_range_min'] is not None and
-                  rule['port_range_max'] is not None and
-                  rule['port_range_min'] <= rule['port_range_max']):
+            if (rule['port_range_min'] is not None and
+                    rule['port_range_max'] is not None and
+                    rule['port_range_min'] <= rule['port_range_max']):
                 # When min/max are the same it is just a single port
                 pass
             else:
@@ -862,8 +860,6 @@ class SecurityGroupDbMixin(ext_sg.SecurityGroupPluginBase,
 
         :returns: the default security group id for given tenant.
         """
-        if not extensions.is_extension_supported(self, 'security-group'):
-            return
         default_group_id = self._get_default_sg_id(context, tenant_id)
         if default_group_id:
             return default_group_id
@@ -922,8 +918,7 @@ class SecurityGroupDbMixin(ext_sg.SecurityGroupPluginBase,
             port_project = port.get('tenant_id')
             default_sg = self._ensure_default_security_group(context,
                                                              port_project)
-            if default_sg:
-                port[ext_sg.SECURITYGROUPS] = [default_sg]
+            port[ext_sg.SECURITYGROUPS] = [default_sg]
 
     def _check_update_deletes_security_groups(self, port):
         """Return True if port has as a security group and it's value
