@@ -148,8 +148,7 @@ class NetworkSegmentRange(base.NeutronDbObject):
                 .filter(
                     segments_model.NetworkSegment.network_id ==
                     models_v2.Network.id)).all()
-        return {segmentation_id: project_id
-                for segmentation_id, project_id in alloc_used}
+        return dict(alloc_used)
 
     @classmethod
     def _build_query_segments(cls, context, model, network_type, **filters):
@@ -191,8 +190,7 @@ class NetworkSegmentRange(base.NeutronDbObject):
             shared_ranges = context.session.query(cls.db_model).filter(
                 and_(cls.db_model.network_type == network_type,
                      cls.db_model.shared == sql.expression.true()))
-            if (network_type == constants.TYPE_VLAN and
-                    'physical_network' in _filters):
+            if network_type == constants.TYPE_VLAN:
                 shared_ranges.filter(cls.db_model.physical_network ==
                                      _filters['physical_network'])
             segment_ids = set([])
@@ -208,8 +206,7 @@ class NetworkSegmentRange(base.NeutronDbObject):
                 and_(cls.db_model.project_id != project_id,
                      cls.db_model.project_id.isnot(None),
                      cls.db_model.network_type == network_type))
-            if (network_type == constants.TYPE_VLAN and
-                    'physical_network' in _filters):
+            if network_type == constants.TYPE_VLAN:
                 other_project_ranges = other_project_ranges.filter(
                     cls.db_model.physical_network ==
                     _filters['physical_network'])
