@@ -248,11 +248,6 @@ class PortDNS(base.NeutronDbObject):
         'dns_domain': common_types.DomainNameField(),
     }
 
-    def obj_make_compatible(self, primitive, target_version):
-        _target_version = versionutils.convert_version_to_tuple(target_version)
-        if _target_version < (1, 1):
-            primitive.pop('dns_domain', None)
-
 
 @base.NeutronObjectRegistry.register
 class SecurityGroupPortBinding(base.NeutronDbObject):
@@ -420,8 +415,15 @@ class Port(base.NeutronDbObject):
                 kwargs['id'] = list(set(port_ids) & set(ports_with_sg))
             else:
                 kwargs['id'] = ports_with_sg
-        return super(Port, cls).get_objects(context, _pager, validate_filters,
-                                            **kwargs)
+        port_array = super(Port, cls).get_objects(context, _pager,
+                                                  validate_filters,
+                                                  **kwargs)
+        sg_count = len(security_group_ids) if security_group_ids else 0
+        LOG.debug("Time-cost: Fetching %(port_count)s ports in %(sg_count)s "
+                  "security groups",
+                  {'port_count': len(port_array),
+                   'sg_count': sg_count})
+        return port_array
 
     @classmethod
     def get_auto_deletable_port_ids_and_proper_port_count_by_segment(
@@ -503,8 +505,6 @@ class Port(base.NeutronDbObject):
 
     def obj_make_compatible(self, primitive, target_version):
         _target_version = versionutils.convert_version_to_tuple(target_version)
-        if _target_version < (1, 1):
-            primitive.pop('data_plane_status', None)
         if _target_version < (1, 2):
             binding_levels = primitive.get('binding_levels', [])
             for lvl in binding_levels:
@@ -604,14 +604,6 @@ class Port(base.NeutronDbObject):
                 ~models_v2.Port.device_owner.in_(excluded_device_owners))
         return [port_binding['port_id'] for port_binding in query.all()]
 
-    @classmethod
-    def get_ports_by_host(cls, context, host):
-        query = context.session.query(models_v2.Port.id).join(
-            ml2_models.PortBinding)
-        query = query.filter(
-            ml2_models.PortBinding.host == host)
-        return [port_id[0] for port_id in query.all()]
-
     @classmethod
     def get_ports_by_binding_type_and_host(cls, context,
                                            binding_type, host):
