@@ -32,7 +32,6 @@ import oslo_messaging
 from oslo_service import loopingcall
 from osprofiler import profiler
 import pyroute2
-import six
 
 from neutron._i18n import _
 from neutron.agent.common import utils
@@ -45,7 +44,6 @@ from neutron.common import config as common_config
 from neutron.common import profiler as setup_profiler
 from neutron.common import utils as n_utils
 from neutron.conf.agent import common as agent_config
-from neutron.conf import service as service_conf
 from neutron.plugins.ml2.drivers.mech_sriov.agent.common import config
 from neutron.plugins.ml2.drivers.mech_sriov.agent.common \
     import exceptions as exc
@@ -173,7 +171,7 @@ class SriovNicSwitchAgent(object):
 
         # TODO(mangelajo): optimize resource_versions (see ovs agent)
         self.agent_state = {
-            'binary': 'neutron-sriov-nic-agent',
+            'binary': n_constants.AGENT_PROCESS_NIC_SWITCH,
             'host': self.conf.host,
             'topic': n_constants.L2_AGENT_TOPIC,
             'configurations': configurations,
@@ -522,8 +520,7 @@ class SriovNicAgentConfigParser(object):
             cfg.CONF.SRIOV_NIC.resource_provider_inventory_defaults)
         self.rp_hypervisors = utils.default_rp_hypervisors(
             cfg.CONF.SRIOV_NIC.resource_provider_hypervisors,
-            self.device_mappings,
-            cfg.CONF.SRIOV_NIC.resource_provider_default_hypervisor,
+            self.device_mappings
         )
         self._validate()
 
@@ -536,7 +533,7 @@ class SriovNicAgentConfigParser(object):
         exists in device mappings.
         """
         dev_net_set = set(itertools.chain.from_iterable(
-                          six.itervalues(self.device_mappings)))
+            self.device_mappings.values()))
         for dev_name in self.exclude_devices.keys():
             if dev_name not in dev_net_set:
                 raise ValueError(_(
@@ -551,8 +548,6 @@ def main():
 
     common_config.setup_logging()
     agent_config.setup_privsep()
-    service_conf.register_service_opts(service_conf.RPC_EXTRA_OPTS, cfg.CONF)
-
     try:
         config_parser = SriovNicAgentConfigParser()
         config_parser.parse()
@@ -584,6 +579,6 @@ def main():
         LOG.exception("Agent Initialization Failed")
         raise SystemExit(1)
     # Start everything.
-    setup_profiler.setup("neutron-sriov-nic-agent", cfg.CONF.host)
+    setup_profiler.setup(n_constants.AGENT_PROCESS_NIC_SWITCH, cfg.CONF.host)
     LOG.info("Agent initialized successfully, now running... ")
     agent.daemon_loop()
