@@ -59,8 +59,7 @@ MAC_SPOOF_TABLE = 25
 
 # Table to decide whether further filtering is needed
 TRANSIENT_TABLE = 60
-LOCAL_MAC_DIRECT = 61
-TRANSIENT_EGRESS_TABLE = 62
+TRANSIENT_EGRESS_TABLE = 61
 
 # Tables used for ovs firewall
 BASE_EGRESS_TABLE = 71
@@ -90,7 +89,6 @@ INT_BR_ALL_TABLES = (
     CANARY_TABLE,
     ARP_SPOOF_TABLE,
     MAC_SPOOF_TABLE,
-    LOCAL_MAC_DIRECT,
     TRANSIENT_TABLE,
     TRANSIENT_EGRESS_TABLE,
     BASE_EGRESS_TABLE,
