@@ -27,6 +27,7 @@ from ovs.stream import Stream
 from ovsdbapp.backend.ovs_idl import connection
 from ovsdbapp.backend.ovs_idl import event as row_event
 from ovsdbapp.backend.ovs_idl import idlutils
+from ovsdbapp import event
 
 from neutron.common.ovn import constants as ovn_const
 from neutron.common.ovn import exceptions
@@ -34,7 +35,6 @@ from neutron.common.ovn import hash_ring_manager
 from neutron.common.ovn import utils
 from neutron.conf.plugins.ml2.drivers.ovn import ovn_conf
 from neutron.db import ovn_hash_ring_db
-from neutron.plugins.ml2.drivers.ovn.mech_driver.ovsdb import backports
 
 
 CONF = cfg.CONF
@@ -220,7 +220,7 @@ class PortBindingChassisEvent(row_event.RowEvent):
     When a chassisredirect port is updated with chassis, this event get
     generated. We will update corresponding router's gateway port with
     the chassis's host_id. Later, users can check router's gateway port
-    host_id to find the location of master HA router.
+    host_id to find the location of primary HA router.
     """
 
     def __init__(self, driver):
@@ -358,23 +358,16 @@ class NeutronPgDropPortGroupCreated(row_event.WaitEvent):
         self.event_name = 'PortGroupCreated'
 
 
-class OvnDbNotifyHandler(backports.RowEventHandler):
+class OvnDbNotifyHandler(event.RowEventHandler):
     def __init__(self, driver):
         super(OvnDbNotifyHandler, self).__init__()
         self.driver = driver
 
 
-class Ml2OvnIdlBase(connection.OvsdbIdl):
-    def __init__(self, remote, schema, probe_interval=(), **kwargs):
-        if probe_interval == ():  # None is a valid value to pass
-            probe_interval = ovn_conf.get_ovn_ovsdb_probe_interval()
-        super(Ml2OvnIdlBase, self).__init__(
-            remote, schema, probe_interval=probe_interval, **kwargs)
+class BaseOvnIdl(connection.OvsdbIdl):
 
-
-class BaseOvnIdl(Ml2OvnIdlBase):
     def __init__(self, remote, schema):
-        self.notify_handler = backports.RowEventHandler()
+        self.notify_handler = event.RowEventHandler()
         super(BaseOvnIdl, self).__init__(remote, schema)
 
     @classmethod
@@ -388,7 +381,7 @@ class BaseOvnIdl(Ml2OvnIdlBase):
         self.notify_handler.notify(event, row, updates)
 
 
-class BaseOvnSbIdl(Ml2OvnIdlBase):
+class BaseOvnSbIdl(connection.OvsdbIdl):
     @classmethod
     def from_server(cls, connection_string, schema_name):
         _check_and_set_ssl_files(schema_name)
@@ -537,13 +530,11 @@ class OvnSbIdl(OvnIdlDistributedLock):
         helper = idlutils.get_schema_helper(connection_string, schema_name)
         if 'Chassis_Private' in helper.schema_json['tables']:
             helper.register_table('Chassis_Private')
-        if 'FDB' in helper.schema_json['tables']:
-            helper.register_table('FDB')
         helper.register_table('Chassis')
         helper.register_table('Encap')
         helper.register_table('Port_Binding')
         helper.register_table('Datapath_Binding')
-        helper.register_table('Connection')
+        helper.register_table('MAC_Binding')
         return cls(driver, connection_string, helper)
 
     def post_connect(self):
@@ -572,11 +563,9 @@ class OvnInitPGNbIdl(OvnIdl):
 
     def __init__(self, driver, remote, schema):
         super(OvnInitPGNbIdl, self).__init__(driver, remote, schema)
-        # self.cond_change() doesn't work here because we are setting the
-        # condition *before an initial monitor request is made* so there is
-        # no previous session whose condition we wish to change
-        self.tables['Port_Group'].condition = [
-            ['name', '==', ovn_const.OVN_DROP_PORT_GROUP_NAME]]
+        self.cond_change(
+            'Port_Group',
+            [['name', '==', ovn_const.OVN_DROP_PORT_GROUP_NAME]])
         self.neutron_pg_drop_event = NeutronPgDropPortGroupCreated()
         self.notify_handler.watch_event(self.neutron_pg_drop_event)
 
