@@ -10,8 +10,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import ctypes
-from ctypes import util as ctypes_util
 import errno
 import os
 import socket
@@ -29,6 +27,7 @@ from pyroute2 import netns
 
 from neutron._i18n import _
 from neutron import privileged
+from neutron.privileged.agent import linux as priv_linux
 
 
 LOG = logging.getLogger(__name__)
@@ -37,21 +36,6 @@ _IP_VERSION_FAMILY_MAP = {4: socket.AF_INET, 6: socket.AF_INET6}
 
 NETNS_RUN_DIR = '/var/run/netns'
 
-_CDLL = None
-
-
-def _get_cdll():
-    global _CDLL
-    if not _CDLL:
-        # NOTE(ralonsoh): from https://docs.python.org/3.6/library/
-        # ctypes.html#ctypes.PyDLL: "Instances of this class behave like CDLL
-        # instances, except that the Python GIL is not released during the
-        # function call, and after the function execution the Python error
-        # flag is checked."
-        # Check https://bugs.launchpad.net/neutron/+bug/1870352
-        _CDLL = ctypes.PyDLL(ctypes_util.find_library('c'), use_errno=True)
-    return _CDLL
-
 
 def _get_scope_name(scope):
     """Return the name of the scope (given as a number), or the scope number
@@ -206,7 +190,7 @@ def get_iproute(namespace):
     # `NetNS` -- RTNL API to another network namespace
     if namespace:
         # do not try and create the namespace
-        return pyroute2.NetNS(namespace, flags=0)
+        return pyroute2.NetNS(namespace, flags=0, libc=priv_linux.get_cdll())
     else:
         return pyroute2.IPRoute()
 
@@ -257,14 +241,18 @@ def _translate_ip_device_exception(e, device=None, namespace=None):
 
 def get_link_id(device, namespace, raise_exception=True):
     with get_iproute(namespace) as ip:
-        link_id = ip.link_lookup(ifname=device)
+        # TODO(ralonsoh): remove try block when the mininimum pyroute2 version
+        # is >= 0.5.13
+        try:
+            link_id = ip.link_lookup(ifname=device)
+        except NetlinkError:
+            link_id = None
     if not link_id or len(link_id) < 1:
         if raise_exception:
             raise NetworkInterfaceNotFound(device=device, namespace=namespace)
-        else:
-            LOG.debug('Interface %(dev)s not found in namespace %(namespace)s',
-                      {'dev': device, 'namespace': namespace})
-            return None
+        LOG.debug('Interface %(dev)s not found in namespace %(namespace)s',
+                  {'dev': device, 'namespace': namespace})
+        return None
     return link_id[0]
 
 
@@ -415,6 +403,25 @@ def set_link_vf_feature(device, namespace, vf_config):
     return _run_iproute_link("set", device, namespace=namespace, vf=vf_config)
 
 
+@privileged.default.entrypoint
+def set_link_bridge_forward_delay(device, forward_delay, namespace=None):
+    return _run_iproute_link('set', device, namespace=namespace,
+                             kind='bridge', br_forward_delay=forward_delay)
+
+
+@privileged.default.entrypoint
+def set_link_bridge_stp(device, stp, namespace=None):
+    return _run_iproute_link('set', device, namespace=namespace,
+                             kind='bridge', br_stp_state=stp)
+
+
+@privileged.default.entrypoint
+def set_link_bridge_master(device, bridge, namespace=None):
+    bridge_idx = get_link_id(bridge, namespace) if bridge else 0
+    return _run_iproute_link('set', device, namespace=namespace,
+                             master=bridge_idx)
+
+
 @privileged.default.entrypoint
 def get_link_attributes(device, namespace):
     link = _run_iproute_link("get", device, namespace)[0]
@@ -531,19 +538,11 @@ def create_netns(name, **kwargs):
 
     :param name: The name of the namespace to create
     """
-    pid = os.fork()
-    if pid == 0:
-        try:
-            netns.create(name, libc=_get_cdll())
-        except OSError as e:
-            if e.errno != errno.EEXIST:
-                os._exit(1)
-        except Exception:
-            os._exit(1)
-        os._exit(0)
-    else:
-        if os.waitpid(pid, 0)[1]:
-            raise RuntimeError(_('Error creating namespace %s') % name)
+    try:
+        netns.create(name, libc=priv_linux.get_cdll())
+    except OSError as e:
+        if e.errno != errno.EEXIST:
+            raise
 
 
 @privileged.default.entrypoint
@@ -553,7 +552,7 @@ def remove_netns(name, **kwargs):
     :param name: The name of the namespace to remove
     """
     try:
-        netns.remove(name, libc=_get_cdll())
+        netns.remove(name, libc=priv_linux.get_cdll())
     except OSError as e:
         if e.errno != errno.ENOENT:
             raise
@@ -645,9 +644,8 @@ def list_ip_rules(namespace, ip_version, match=None, **kwargs):
                 family=_IP_VERSION_FAMILY_MAP[ip_version],
                 match=match, **kwargs))
             for rule in rules:
-                rule['attrs'] = {
-                    key: value for key, value
-                    in ((item[0], item[1]) for item in rule['attrs'])}
+                rule['attrs'] = dict(
+                    (item[0], item[1]) for item in rule['attrs'])
             return rules
 
     except OSError as e:
