@@ -12,12 +12,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import os
-from os import path
 import re
 
 from oslo_concurrency import processutils
-from oslo_utils import fileutils
 
 from neutron import privileged
 
@@ -43,13 +40,3 @@ def _find_listen_pids_namespace(namespace):
         if m:
             pids.add(m.group('pid'))
     return list(pids)
-
-
-@privileged.default.entrypoint
-def delete_if_exists(_path, remove=os.unlink):
-    fileutils.delete_if_exists(_path, remove=remove)
-
-
-@privileged.default.entrypoint
-def path_exists(_path):
-    return path.exists(_path)
