@@ -12,11 +12,14 @@
 #    under the License.
 #
 
-from neutron_lib.api.definitions import dns as dns_apidef
+from neutron.db import dns_db
+from neutron.db import extraroute_db
+from neutron.db import l3_gwmode_db
+from neutron.db.models import l3 as l3_models
+from neutron.quota import resource_registry
 from neutron_lib.api.definitions import external_net
 from neutron_lib.api.definitions import portbindings
 from neutron_lib.api.definitions import provider_net as pnet
-from neutron_lib.api import extensions as api_extensions
 from neutron_lib.callbacks import events
 from neutron_lib.callbacks import registry
 from neutron_lib.callbacks import resources
@@ -34,15 +37,13 @@ from neutron.common.ovn import constants as ovn_const
 from neutron.common.ovn import extensions
 from neutron.common.ovn import utils
 from neutron.db.availability_zone import router as router_az_db
-from neutron.db import dns_db
-from neutron.db import extraroute_db
 from neutron.db import l3_fip_port_details
-from neutron.db import l3_gwmode_db
-from neutron.db.models import l3 as l3_models
 from neutron.db import ovn_revision_numbers_db as db_rev
 from neutron.plugins.ml2.drivers.ovn.mech_driver.ovsdb import ovn_client
-from neutron.quota import resource_registry
 from neutron.scheduler import l3_ovn_scheduler
+from neutron.services.portforwarding.drivers.ovn import driver \
+    as port_forwarding
+
 from neutron.services.ovn_l3 import exceptions as ovn_l3_exc
 
 
@@ -65,7 +66,7 @@ class OVNL3RouterPlugin(service_base.ServicePluginBase,
 
     # TODO(mjozefcz): Start consuming it from neutron-lib
     # once available.
-    _supported_extension_aliases = (
+    supported_extension_aliases = (
         extensions.ML2_SUPPORTED_API_EXTENSIONS_OVN_L3)
 
     @resource_registry.tracked_resources(router=l3_models.Router,
@@ -77,6 +78,7 @@ class OVNL3RouterPlugin(service_base.ServicePluginBase,
         self._mech = None
         self._ovn_client_inst = None
         self.scheduler = l3_ovn_scheduler.get_scheduler()
+        self.port_forwarding = port_forwarding.OVNPortForwarding(self)
         self._register_precommit_callbacks()
 
     def _register_precommit_callbacks(self):
@@ -87,20 +89,6 @@ class OVNL3RouterPlugin(service_base.ServicePluginBase,
             self.create_floatingip_precommit, resources.FLOATING_IP,
             events.PRECOMMIT_CREATE)
 
-    @staticmethod
-    def disable_dns_extension_by_extension_drivers(aliases):
-        core_plugin = directory.get_plugin()
-        if not api_extensions.is_extension_supported(
-                core_plugin, dns_apidef.ALIAS):
-            aliases.remove(dns_apidef.ALIAS)
-
-    @property
-    def supported_extension_aliases(self):
-        if not hasattr(self, '_aliases'):
-            self._aliases = self._supported_extension_aliases[:]
-            self.disable_dns_extension_by_extension_drivers(self._aliases)
-        return self._aliases
-
     @property
     def _ovn_client(self):
         if self._ovn_client_inst is None:
@@ -393,7 +381,7 @@ class OVNL3RouterPlugin(service_base.ServicePluginBase,
             # Remove any invalid gateway chassis from the list, otherwise
             # we can have a situation where all existing_chassis are invalid
             existing_chassis = self._ovn.get_gateway_chassis_binding(g_name)
-            master = existing_chassis[0] if existing_chassis else None
+            primary = existing_chassis[0] if existing_chassis else None
             existing_chassis = self.scheduler.filter_existing_chassis(
                 nb_idl=self._ovn, gw_chassis=all_gw_chassis,
                 physnet=physnet, chassis_physnets=chassis_with_physnets,
@@ -406,21 +394,21 @@ class OVNL3RouterPlugin(service_base.ServicePluginBase,
             chassis = self.scheduler.select(
                 self._ovn, self._sb_ovn, g_name, candidates=candidates,
                 existing_chassis=existing_chassis)
-            if master and master != chassis[0]:
-                if master not in chassis:
-                    LOG.debug("Master gateway chassis %(old)s "
+            if primary and primary != chassis[0]:
+                if primary not in chassis:
+                    LOG.debug("Primary gateway chassis %(old)s "
                               "has been removed from the system. Moving "
                               "gateway %(gw)s to other chassis %(new)s.",
                               {'gw': g_name,
-                               'old': master,
+                               'old': primary,
                                'new': chassis[0]})
                 else:
-                    LOG.debug("Gateway %s is hosted at %s.", g_name, master)
-                    # NOTE(mjozefcz): It means scheduler moved master chassis
+                    LOG.debug("Gateway %s is hosted at %s.", g_name, primary)
+                    # NOTE(mjozefcz): It means scheduler moved primary chassis
                     # to other gw based on scheduling method. But we don't
-                    # want network flap - so moving actual master to be on
+                    # want network flap - so moving actual primary to be on
                     # the top.
-                    index = chassis.index(master)
+                    index = chassis.index(primary)
                     chassis[0], chassis[index] = chassis[index], chassis[0]
             # NOTE(dalvarez): Let's commit the changes in separate transactions
             # as we will rely on those for scheduling subsequent gateways.
