@@ -14,6 +14,7 @@
 #    under the License.
 
 import collections
+import copy
 
 import netaddr
 from neutron_lib.api.definitions import expose_port_forwarding_in_fip
@@ -31,7 +32,7 @@ from neutron_lib.exceptions import l3 as lib_l3_exc
 from neutron_lib.objects import exceptions as obj_exc
 from neutron_lib.plugins import constants
 from neutron_lib.plugins import directory
-from oslo_db import exception as oslo_db_exc
+from oslo_config import cfg
 from oslo_log import log as logging
 
 from neutron._i18n import _
@@ -44,7 +45,9 @@ from neutron.extensions import floating_ip_port_forwarding as fip_pf
 from neutron.objects import base as base_obj
 from neutron.objects import port_forwarding as pf
 from neutron.objects import router as l3_obj
+from neutron.services.portforwarding import callbacks
 from neutron.services.portforwarding.common import exceptions as pf_exc
+from neutron.services.portforwarding import constants as pf_consts
 
 LOG = logging.getLogger(__name__)
 
@@ -52,6 +55,28 @@ LOG = logging.getLogger(__name__)
 PORT_FORWARDING_FLOATINGIP_KEY = '_pf_floatingips'
 
 
+def _required_service_plugins():
+    SvcPlugin = collections.namedtuple('SvcPlugin', 'plugin uses_rpc')
+    l3_router = SvcPlugin(l3.ROUTER, True)
+    supported_svc_plugins = [
+        l3_router,
+        SvcPlugin('ovn-router', False),
+        SvcPlugin('neutron.services.ovn_l3.plugin.OVNL3RouterPlugin', False)]
+    plugins = []
+    rpc_required = False
+    try:
+        for svc in supported_svc_plugins:
+            if svc.plugin in cfg.CONF.service_plugins:
+                plugins.append(svc.plugin)
+                rpc_required |= svc.uses_rpc
+    except cfg.NoSuchOptError:
+        pass
+    if plugins:
+        return plugins, rpc_required
+    # Use l3_router as required service plugin if no other was provided.
+    return [l3_router.plugin], l3_router.uses_rpc
+
+
 @resource_extend.has_resource_extenders
 @registry.has_registry_receivers
 class PortForwardingPlugin(fip_pf.PortForwardingPluginBase):
@@ -60,7 +85,8 @@ class PortForwardingPlugin(fip_pf.PortForwardingPluginBase):
     This class implements a Port Forwarding plugin.
     """
 
-    required_service_plugins = ['router']
+    required_service_plugins, _rpc_notifications_required = \
+        _required_service_plugins()
 
     supported_extension_aliases = [apidef.ALIAS,
                                    expose_port_forwarding_in_fip.ALIAS,
@@ -72,9 +98,12 @@ class PortForwardingPlugin(fip_pf.PortForwardingPluginBase):
 
     def __init__(self):
         super(PortForwardingPlugin, self).__init__()
-        self.push_api = resources_rpc.ResourcesPushRpcApi()
+        self.push_api = resources_rpc.ResourcesPushRpcApi() \
+            if self._rpc_notifications_required else None
         self.l3_plugin = directory.get_plugin(constants.L3)
         self.core_plugin = directory.get_plugin()
+        registry.publish(pf_consts.PORT_FORWARDING_PLUGIN, events.AFTER_INIT,
+                         self)
 
     @staticmethod
     @resource_extend.extends([l3.FLOATINGIPS])
@@ -224,8 +253,14 @@ class PortForwardingPlugin(fip_pf.PortForwardingPluginBase):
                     pf_resource.delete()
                     remove_port_forwarding_list.append(pf_resource)
 
-        self.push_api.push(context, remove_port_forwarding_list,
-                           rpc_events.DELETED)
+        if self._rpc_notifications_required:
+            self.push_api.push(context, remove_port_forwarding_list,
+                               rpc_events.DELETED)
+        registry_notify_payload = [
+            callbacks.PortForwardingPayload(context, original_pf=pf_obj) for
+            pf_obj in remove_port_forwarding_list]
+        registry.notify(pf_consts.PORT_FORWARDING, events.AFTER_DELETE, self,
+                        payload=registry_notify_payload)
 
     def _get_internal_ip_subnet(self, request_ip, fixed_ips):
         request_ip = netaddr.IPNetwork(request_ip)
@@ -347,7 +382,12 @@ class PortForwardingPlugin(fip_pf.PortForwardingPluginBase):
                 raise lib_exc.BadRequest(resource=apidef.RESOURCE_NAME,
                                          msg=message)
 
-            self.push_api.push(context, [pf_obj], rpc_events.CREATED)
+            if self._rpc_notifications_required:
+                self.push_api.push(context, [pf_obj], rpc_events.CREATED)
+            registry.notify(pf_consts.PORT_FORWARDING, events.AFTER_CREATE,
+                            self,
+                            payload=[callbacks.PortForwardingPayload(context,
+                                current_pf=pf_obj)])
             return pf_obj
 
     @db_base_plugin_common.convert_result_to_dict
@@ -365,6 +405,7 @@ class PortForwardingPlugin(fip_pf.PortForwardingPluginBase):
                 pf_obj = pf.PortForwarding.get_object(context, id=id)
                 if not pf_obj:
                     raise pf_exc.PortForwardingNotFound(id=id)
+                original_pf_obj = copy.deepcopy(pf_obj)
                 ori_internal_port_id = pf_obj.internal_port_id
                 if new_internal_port_id and (new_internal_port_id !=
                                              ori_internal_port_id):
@@ -389,7 +430,7 @@ class PortForwardingPlugin(fip_pf.PortForwardingPluginBase):
                 pf_obj.update_fields(port_forwarding, reset_changes=True)
                 self._check_port_forwarding_update(context, pf_obj)
                 pf_obj.update()
-        except oslo_db_exc.DBDuplicateEntry:
+        except obj_exc.NeutronDbObjectDuplicateEntry:
             (__, conflict_params) = self._find_existing_port_forwarding(
                 context, floatingip_id, pf_obj.to_dict())
             message = _("A duplicate port forwarding entry with same "
@@ -397,7 +438,11 @@ class PortForwardingPlugin(fip_pf.PortForwardingPluginBase):
                         "are %s") % conflict_params
             raise lib_exc.BadRequest(resource=apidef.RESOURCE_NAME,
                                      msg=message)
-        self.push_api.push(context, [pf_obj], rpc_events.UPDATED)
+        if self._rpc_notifications_required:
+            self.push_api.push(context, [pf_obj], rpc_events.UPDATED)
+        registry.notify(pf_consts.PORT_FORWARDING, events.AFTER_UPDATE, self,
+                        payload=[callbacks.PortForwardingPayload(context,
+                            current_pf=pf_obj, original_pf=original_pf_obj)])
         return pf_obj
 
     def _check_router_match(self, context, fip_obj, router_id, pf_dict):
@@ -537,7 +582,11 @@ class PortForwardingPlugin(fip_pf.PortForwardingPluginBase):
                 fip_obj.update_fields({'router_id': None})
                 fip_obj.update()
             pf_obj.delete()
-        self.push_api.push(context, [pf_obj], rpc_events.DELETED)
+        if self._rpc_notifications_required:
+            self.push_api.push(context, [pf_obj], rpc_events.DELETED)
+        registry.notify(pf_consts.PORT_FORWARDING, events.AFTER_DELETE, self,
+                        payload=[callbacks.PortForwardingPayload(
+                            context, original_pf=pf_obj)])
 
     def sync_port_forwarding_fip(self, context, routers):
         if not routers:
