@@ -17,10 +17,10 @@ from datetime import datetime
 import errno
 import os
 import shutil
+from unittest import mock
 import warnings
 
 import fixtures
-import mock
 from neutron_lib import fixture
 from neutron_lib.plugins import constants
 from neutron_lib.plugins import directory
@@ -40,15 +40,14 @@ from neutron.conf.plugins.ml2.drivers.ovn import ovn_conf
 # Load all the models to register them into SQLAlchemy metadata before using
 # the SqlFixture
 from neutron.db import models  # noqa
+from neutron import manager
 from neutron.plugins.ml2.drivers.ovn.mech_driver.ovsdb import worker
 from neutron.plugins.ml2.drivers import type_geneve  # noqa
-from neutron import service  # noqa
 from neutron.tests import base
 from neutron.tests.common import base as common_base
 from neutron.tests.common import helpers
 from neutron.tests.functional.resources import process
 from neutron.tests.unit.plugins.ml2 import test_plugin
-import neutron.wsgi
 
 LOG = log.getLogger(__name__)
 
@@ -174,7 +173,6 @@ class TestOVNFunctionalBase(test_plugin.Ml2PluginV2TestCase,
         ovn_conf.cfg.CONF.set_override('dns_servers',
                                        ['10.10.10.10'],
                                        group='ovn')
-        ovn_conf.cfg.CONF.set_override('api_workers', 1)
 
         self.addCleanup(exts.PluginAwareExtensionManager.clear_instance)
         super(TestOVNFunctionalBase, self).setUp()
@@ -186,6 +184,10 @@ class TestOVNFunctionalBase(test_plugin.Ml2PluginV2TestCase,
         self.mech_driver = mm.mech_drivers['ovn'].obj
         self.l3_plugin = directory.get_plugin(constants.L3)
         self.segments_plugin = directory.get_plugin('segments')
+        # OVN does not use RPC: disable it for port-forwarding tests
+        self.pf_plugin = manager.NeutronManager.load_class_for_provider(
+            'neutron.service_plugins', 'port_forwarding')()
+        self.pf_plugin._rpc_notifications_required = False
         self.ovsdb_server_mgr = None
         self.ovn_northd_mgr = None
         self.maintenance_worker = maintenance_worker
@@ -266,10 +268,10 @@ class TestOVNFunctionalBase(test_plugin.Ml2PluginV2TestCase,
         set_cfg('ovn_sb_ca_cert', self.ovsdb_server_mgr.ca_cert, 'ovn')
 
         # NOTE(mjozefcz): We can find occasional functional test
-        # failures because of low timeout value - set it to 15
+        # failures because of low timeout value - set it to 30
         # seconds, should be enought. More info: 1868110
         cfg.CONF.set_override(
-            'ovsdb_connection_timeout', 15,
+            'ovsdb_connection_timeout', 30,
             'ovn')
 
         class TriggerCls(mock.MagicMock):
@@ -280,8 +282,6 @@ class TestOVNFunctionalBase(test_plugin.Ml2PluginV2TestCase,
         if self.maintenance_worker:
             trigger_cls.trigger.__self__.__class__ = worker.MaintenanceWorker
             cfg.CONF.set_override('neutron_sync_mode', 'off', 'ovn')
-        else:
-            trigger_cls.trigger.__self__.__class__ = neutron.wsgi.WorkerService
 
         self.addCleanup(self._collect_processes_logs)
         self.addCleanup(self.stop)
@@ -349,18 +349,11 @@ class TestOVNFunctionalBase(test_plugin.Ml2PluginV2TestCase,
         # fake chassis but from the SB db point of view, 'ip' column can be
         # any string so we could add entries with ip='172.24.4.1000'.
         self._counter += 1
-        chassis = self.sb_api.chassis_add(
+        self.sb_api.chassis_add(
             name, ['geneve'], '172.24.4.%d' % self._counter,
             external_ids=external_ids, hostname=host).execute(check_error=True)
-        if self.sb_api.is_table_present('Chassis_Private'):
-            self.sb_api.db_create(
-                'Chassis_Private', name=name, external_ids=external_ids,
-                chassis=chassis.uuid).execute(check_error=True)
         return name
 
     def del_fake_chassis(self, chassis, if_exists=True):
         self.sb_api.chassis_del(
             chassis, if_exists=if_exists).execute(check_error=True)
-        if self.sb_api.is_table_present('Chassis_Private'):
-            self.sb_api.db_destroy(
-                'Chassis_Private', chassis).execute(check_error=True)
