@@ -12,9 +12,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import copy
+from unittest import mock
 
-import mock
 from neutron_lib.api.definitions import portbindings
 from neutron_lib import constants as lib_constants
 from oslo_config import cfg
@@ -24,7 +23,6 @@ from oslo_utils import uuidutils
 from neutron.agent.l3 import agent as l3_agent
 from neutron.agent.l3 import dvr_edge_ha_router as dvr_edge_ha_rtr
 from neutron.agent.l3 import dvr_edge_router as dvr_edge_rtr
-from neutron.agent.l3 import dvr_fip_ns
 from neutron.agent.l3 import dvr_local_router as dvr_router
 from neutron.agent.l3 import link_local_allocator as lla
 from neutron.agent.l3 import router_info
@@ -41,9 +39,6 @@ from neutron.tests.common import l3_test_common
 _uuid = uuidutils.generate_uuid
 FIP_PRI = 32768
 HOSTNAME = 'myhost'
-FIP_RULE_PRIO_LIST = [['fip_1', 'fixed_ip_1', 'prio_1'],
-                      ['fip_2', 'fixed_ip_2', 'prio_2'],
-                      ['fip_3', 'fixed_ip_3', 'prio_3']]
 
 
 class TestDvrRouterOperations(base.BaseTestCase):
@@ -122,10 +117,6 @@ class TestDvrRouterOperations(base.BaseTestCase):
             'oslo_service.loopingcall.FixedIntervalLoopingCall')
         self.looping_call_p.start()
 
-        self.mock_load_fip_p = mock.patch.object(dvr_router.DvrLocalRouter,
-                                                 '_load_used_fip_information')
-        self.mock_load_fip = self.mock_load_fip_p.start()
-
         subnet_id_1 = _uuid()
         subnet_id_2 = _uuid()
         self.snat_ports = [{'subnets': [{'cidr': '152.2.0.0/16',
@@ -164,7 +155,9 @@ class TestDvrRouterOperations(base.BaseTestCase):
         kwargs['router'] = router
         kwargs['agent_conf'] = self.conf
         kwargs['interface_driver'] = mock.Mock()
-        return dvr_router.DvrLocalRouter(HOSTNAME, **kwargs)
+        with mock.patch.object(dvr_router.DvrLocalRouter,
+                               'load_used_fip_information'):
+            return dvr_router.DvrLocalRouter(HOSTNAME, **kwargs)
 
     def _set_ri_kwargs(self, agent, router_id, router):
         self.ri_kwargs['agent'] = agent
@@ -232,40 +225,32 @@ class TestDvrRouterOperations(base.BaseTestCase):
             self.assertTrue(
                 ri.fip_ns.create_rtr_2_fip_link.called)
 
-    @mock.patch.object(ip_lib, 'add_ip_rule')
-    def test__load_used_fip_information(self, mock_add_ip_rule):
-        # This test will simulate how "DvrLocalRouter" reloads the FIP
-        # information from both the FipNamespace._rule_priorities state file
-        # and the namespace "ip rule" list.
-        router = self._create_router()
-        self.mock_load_fip_p.stop()
-        fip_ns = router.agent.get_fip_ns('net_id')
-
-        # To simulate a partially populated FipNamespace._rule_priorities
-        # state file, we load all FIPs but last.
-        fip_rule_prio_list = copy.deepcopy(FIP_RULE_PRIO_LIST)
-        for idx, (fip, _, _) in enumerate(FIP_RULE_PRIO_LIST[:-1]):
-            prio = fip_ns.allocate_rule_priority(fip)
-            fip_rule_prio_list[idx][2] = prio
-
-        fips = [{'floating_ip_address': fip, 'fixed_ip_address': fixed_ip} for
-                fip, fixed_ip, _ in fip_rule_prio_list]
-        with mock.patch.object(dvr_fip_ns.FipNamespace,
-                               'allocate_rule_priority',
-                               return_value=fip_rule_prio_list[-1][2]), \
-                mock.patch.object(router, '_cleanup_unused_fip_ip_rules'), \
-                mock.patch.object(router, 'get_floating_ips',
-                                  return_value=fips):
-            router._load_used_fip_information()
-
-        mock_add_ip_rule.assert_called_once_with(
-            router.ns_name, fip_rule_prio_list[2][1],
-            table=dvr_fip_ns.FIP_RT_TBL, priority=fip_rule_prio_list[-1][2])
-        self.assertEqual(3, len(router.floating_ips_dict))
-        ret = [[fip, fixed_ip, prio] for fip, (fixed_ip, prio) in
-               router.floating_ips_dict.items()]
-        self.assertEqual(sorted(ret, key=lambda ret: ret[0]),
-                         fip_rule_prio_list)
+    def test_load_used_fip_information(self):
+        router = mock.MagicMock()
+        with mock.patch.object(dvr_router.DvrLocalRouter,
+                               'get_floating_ips') as mock_get_floating_ips:
+            with mock.patch.object(dvr_router.DvrLocalRouter,
+                                   'get_ex_gw_port') as mock_ext_port:
+                mock_ext_port.return_value = {'network_id': _uuid()}
+                fip = {'id': _uuid(),
+                       'host': HOSTNAME,
+                       'floating_ip_address': '15.1.2.3',
+                       'fixed_ip_address': '192.168.0.1',
+                       'floating_network_id': _uuid(),
+                       'port_id': _uuid()}
+                fip_ns = mock.MagicMock()
+                fip_ns.lookup_rule_priority.return_value = 1234
+                mock_get_floating_ips.return_value = [fip]
+                mock_agent = mock.MagicMock()
+                mock_agent.get_fip_ns.return_value = fip_ns
+                kwargs = {'agent': mock_agent,
+                          'router_id': _uuid(),
+                          'router': mock.Mock(),
+                          'agent_conf': self.conf,
+                          'interface_driver': mock.Mock()}
+                router = dvr_router.DvrLocalRouter(HOSTNAME, **kwargs)
+                self.assertEqual({'15.1.2.3': ('192.168.0.1', 1234)},
+                                 router.floating_ips_dict)
 
     def test_get_floating_ips_dvr(self):
         router = mock.MagicMock()
@@ -543,19 +528,11 @@ class TestDvrRouterOperations(base.BaseTestCase):
         ri = dvr_router.DvrLocalRouter(HOSTNAME, **self.ri_kwargs)
         ports = ri.router.get(lib_constants.INTERFACE_KEY, [])
         subnet_id = l3_test_common.get_subnet_id(ports[0])
-        ri.router['_snat_router_interfaces'] = [{
-            'mac_address': 'fa:16:3e:80:8d:80',
-            'fixed_ips': [{'subnet_id': subnet_id,
-                           'ip_address': '1.2.3.10'}]}]
-
         test_ports = [{'mac_address': '00:11:22:33:44:55',
                        'device_owner': lib_constants.DEVICE_OWNER_DHCP,
                        'fixed_ips': [{'ip_address': '1.2.3.4',
                                       'prefixlen': 24,
-                                      'subnet_id': subnet_id}],
-                       'allowed_address_pairs': [
-                           {'ip_address': '10.20.30.40',
-                            'mac_address': '00:11:22:33:44:55'}]},
+                                      'subnet_id': subnet_id}]},
                       {'mac_address': '11:22:33:44:55:66',
                        'device_owner': lib_constants.DEVICE_OWNER_LOADBALANCER,
                        'fixed_ips': [{'ip_address': '1.2.3.5',
@@ -577,10 +554,8 @@ class TestDvrRouterOperations(base.BaseTestCase):
                                '_process_arp_cache_for_internal_port') as parp:
             ri._set_subnet_arp_info(subnet_id)
         self.assertEqual(1, parp.call_count)
-        self.mock_ip_dev.neigh.add.assert_has_calls([
-            mock.call('1.2.3.4', '00:11:22:33:44:55'),
-            mock.call('10.20.30.40', '00:11:22:33:44:55'),
-            mock.call('1.2.3.10', 'fa:16:3e:80:8d:80')])
+        self.mock_ip_dev.neigh.add.assert_called_once_with(
+            '1.2.3.4', '00:11:22:33:44:55')
 
         # Test negative case
         router['distributed'] = False
@@ -886,8 +861,8 @@ class TestDvrRouterOperations(base.BaseTestCase):
         fip = {'id': _uuid()}
         fip_cidr = '11.22.33.44/24'
 
-        ri = dvr_edge_ha_rtr.DvrEdgeHaRouter(HOSTNAME, **self.ri_kwargs)
-        ri.is_router_master = mock.Mock(return_value=False)
+        ri = dvr_edge_ha_rtr.DvrEdgeHaRouter(HOSTNAME, [], **self.ri_kwargs)
+        ri.is_router_primary = mock.Mock(return_value=False)
         ri._add_vip = mock.Mock()
         interface_name = ri.get_snat_external_device_interface_name(
             ri.get_ex_gw_port())
@@ -897,8 +872,8 @@ class TestDvrRouterOperations(base.BaseTestCase):
 
         router[lib_constants.HA_INTERFACE_KEY]['status'] = 'DOWN'
         self._set_ri_kwargs(agent, router['id'], router)
-        ri_1 = dvr_edge_ha_rtr.DvrEdgeHaRouter(HOSTNAME, **self.ri_kwargs)
-        ri_1.is_router_master = mock.Mock(return_value=True)
+        ri_1 = dvr_edge_ha_rtr.DvrEdgeHaRouter(HOSTNAME, [], **self.ri_kwargs)
+        ri_1.is_router_primary = mock.Mock(return_value=True)
         ri_1._add_vip = mock.Mock()
         interface_name = ri_1.get_snat_external_device_interface_name(
             ri_1.get_ex_gw_port())
@@ -908,8 +883,8 @@ class TestDvrRouterOperations(base.BaseTestCase):
 
         router[lib_constants.HA_INTERFACE_KEY]['status'] = 'ACTIVE'
         self._set_ri_kwargs(agent, router['id'], router)
-        ri_2 = dvr_edge_ha_rtr.DvrEdgeHaRouter(HOSTNAME, **self.ri_kwargs)
-        ri_2.is_router_master = mock.Mock(return_value=True)
+        ri_2 = dvr_edge_ha_rtr.DvrEdgeHaRouter(HOSTNAME, [], **self.ri_kwargs)
+        ri_2.is_router_primary = mock.Mock(return_value=True)
         ri_2._add_vip = mock.Mock()
         interface_name = ri_2.get_snat_external_device_interface_name(
             ri_2.get_ex_gw_port())
@@ -930,15 +905,15 @@ class TestDvrRouterOperations(base.BaseTestCase):
         self._set_ri_kwargs(agent, router['id'], router)
         fip_cidr = '11.22.33.44/24'
 
-        ri = dvr_edge_ha_rtr.DvrEdgeHaRouter(HOSTNAME, **self.ri_kwargs)
-        ri.is_router_master = mock.Mock(return_value=False)
+        ri = dvr_edge_ha_rtr.DvrEdgeHaRouter(HOSTNAME, [], **self.ri_kwargs)
+        ri.is_router_primary = mock.Mock(return_value=False)
         ri._remove_vip = mock.Mock()
         ri.remove_centralized_floatingip(fip_cidr)
         ri._remove_vip.assert_called_once_with(fip_cidr)
         super_remove_centralized_floatingip.assert_not_called()
 
-        ri1 = dvr_edge_ha_rtr.DvrEdgeHaRouter(HOSTNAME, **self.ri_kwargs)
-        ri1.is_router_master = mock.Mock(return_value=True)
+        ri1 = dvr_edge_ha_rtr.DvrEdgeHaRouter(HOSTNAME, [], **self.ri_kwargs)
+        ri1.is_router_primary = mock.Mock(return_value=True)
         ri1._remove_vip = mock.Mock()
         ri1.remove_centralized_floatingip(fip_cidr)
         ri1._remove_vip.assert_called_once_with(fip_cidr)
@@ -953,9 +928,10 @@ class TestDvrRouterOperations(base.BaseTestCase):
         router[lib_constants.HA_INTERFACE_KEY]['status'] = 'ACTIVE'
         self.mock_driver.unplug.reset_mock()
         self._set_ri_kwargs(agent, router['id'], router)
-        ri = dvr_edge_ha_rtr.DvrEdgeHaRouter(HOSTNAME, **self.ri_kwargs)
+        ri = dvr_edge_ha_rtr.DvrEdgeHaRouter(HOSTNAME, [], **self.ri_kwargs)
         ri._ha_state_path = self.get_temp_file_path('router_ha_state')
         ri._create_snat_namespace = mock.Mock()
+        ri.update_initial_state = mock.Mock()
         ri._plug_external_gateway = mock.Mock()
         ri.initialize(mock.Mock())
         ri._create_dvr_gateway(mock.Mock(), mock.Mock())
@@ -971,13 +947,14 @@ class TestDvrRouterOperations(base.BaseTestCase):
         self.mock_driver.unplug.reset_mock()
         self._set_ri_kwargs(agent, router['id'], router)
 
-        ri = dvr_edge_ha_rtr.DvrEdgeHaRouter(HOSTNAME, **self.ri_kwargs)
+        ri = dvr_edge_ha_rtr.DvrEdgeHaRouter(HOSTNAME, [], **self.ri_kwargs)
         ri._ha_state_path = self.get_temp_file_path('router_ha_state')
 
         with open(ri._ha_state_path, "w") as f:
-            f.write("master")
+            f.write("primary")
 
         ri._create_snat_namespace = mock.Mock()
+        ri.update_initial_state = mock.Mock()
         ri._plug_external_gateway = mock.Mock()
         with mock.patch("neutron.agent.linux.keepalived."
                         "KeepalivedManager.check_processes",
