@@ -16,16 +16,16 @@ import os.path
 import random
 import re
 import sys
+import time
+from unittest import mock
 
 import ddt
 import eventlet
 from eventlet import queue
-import mock
 import netaddr
 from neutron_lib import constants
 from oslo_log import log as logging
 from osprofiler import profiler
-import six
 import testscenarios
 import testtools
 
@@ -162,8 +162,7 @@ class TestExceptionLogger(base.BaseTestCase):
         def func(i):
             if i == 2:
                 raise RuntimeError(2)
-            else:
-                calls(i)
+            calls(i)
 
         pool = eventlet.GreenPool(4)
         for i in range(0, 4):
@@ -335,7 +334,7 @@ class TestPortRuleMasking(base.BaseTestCase):
 
     def test_port_rule_masking_random_ranges(self):
         # calling randint a bunch of times is really slow
-        randports = sorted(random.sample(six.moves.range(1, 65536), 2000))
+        randports = sorted(random.sample(range(1, 65536), 2000))
         port_max = 0
         for i in randports:
             port_min = port_max
@@ -391,7 +390,7 @@ class TestExcDetails(base.BaseTestCase):
 
     def test_extract_exc_details_no_details_attached(self):
         self.assertIsInstance(
-            utils.extract_exc_details(Exception()), six.text_type)
+            utils.extract_exc_details(Exception()), str)
 
 
 @ddt.ddt
@@ -427,7 +426,7 @@ class TestThrottler(base.BaseTestCase):
 
         def sleep_mock(amount_to_sleep):
             sleep(amount_to_sleep)
-            self.assertGreaterEqual(threshold, amount_to_sleep)
+            self.assertGreater(threshold, amount_to_sleep)
 
         with mock.patch.object(utils.eventlet, "sleep",
                                side_effect=sleep_mock):
@@ -435,8 +434,7 @@ class TestThrottler(base.BaseTestCase):
 
         self.assertEqual(2, orig_function.call_count)
 
-        lock_with_timer = six.get_function_closure(
-            throttled_func)[1].cell_contents
+        lock_with_timer = throttled_func.__closure__[1].cell_contents
         timestamp = lock_with_timer.timestamp - threshold
         lock_with_timer.timestamp = timestamp
 
@@ -538,6 +536,41 @@ class TestRpBandwidthValidator(base.BaseTestCase):
                           self.not_valid_rp_bandwidth, self.device_name_set)
 
 
+class TimerTestCase(base.BaseTestCase):
+
+    def test__getattr(self):
+        with utils.Timer() as timer:
+            time.sleep(1)
+        self.assertLess(timer.total_seconds(), 2)
+        self.assertEqual(1, timer.delta.seconds)
+
+    def test__enter_with_timeout(self):
+        with utils.Timer(timeout=10) as timer:
+            time.sleep(1)
+        self.assertLess(timer.total_seconds(), 2)
+
+    def test__enter_with_timeout_exception(self):
+        msg = r'Timer timeout expired after 1 second\(s\).'
+        with self.assertRaisesRegex(utils.TimerTimeout, msg):
+            with utils.Timer(timeout=1):
+                time.sleep(2)
+
+    def test__enter_with_timeout_no_exception(self):
+        with utils.Timer(timeout=1, raise_exception=False):
+            time.sleep(2)
+
+    def test__iter(self):
+        iterations = []
+        for i in utils.Timer(timeout=2):
+            iterations.append(i)
+            time.sleep(1.1)
+        self.assertEqual(2, len(iterations))
+
+    def test_delta_time_sec(self):
+        with utils.Timer() as timer:
+            self.assertIsInstance(timer.delta_time_sec, float)
+
+
 class SpawnWithOrWithoutProfilerTestCase(
         testscenarios.WithScenarios, base.BaseTestCase):
 
@@ -606,25 +639,3 @@ class SingletonDecoratorTestCase(base.BaseTestCase):
         instance_2 = _TestSingletonClass()
         self.assertEqual(instance_1.__hash__(), instance_2.__hash__())
         self.assertEqual('value1', instance_2.variable)
-
-
-class SkipDecoratorTestCase(base.BaseTestCase):
-
-    def test_skip_exception(self):
-        @utils.skip_exceptions(AttributeError)
-        def raise_attribute_error_single_exception():
-            raise AttributeError()
-
-        @utils.skip_exceptions([AttributeError, IndexError])
-        def raise_attribute_error_exception_list():
-            raise AttributeError()
-
-        raise_attribute_error_single_exception()
-        raise_attribute_error_exception_list()
-
-    def test_skip_exception_fail(self):
-        @utils.skip_exceptions(IndexError)
-        def raise_attribute_error():
-            raise AttributeError()
-
-        self.assertRaises(AttributeError, raise_attribute_error)
