@@ -14,9 +14,10 @@
 #    under the License.
 #
 
+import collections
 import time
+from unittest import mock
 
-import mock
 from neutron_lib import constants as n_const
 from oslo_config import cfg
 from oslo_log import log
@@ -30,6 +31,8 @@ from neutron.tests.unit.plugins.ml2.drivers.openvswitch.agent \
     import test_vlanmanager
 
 
+Switch = collections.namedtuple('Switch', ['br_name'])
+
 # Useful global dummy variables.
 NET_UUID = '3faeebfe-5d37-11e1-a64b-000c29d5f0a7'
 LS_ID = 420
@@ -38,8 +41,8 @@ LV_IDS = [42, 43]
 VIF_ID = '404deaec-5d37-11e1-a64b-000c29d5f0a8'
 VIF_MAC = '3c:09:24:1e:78:23'
 OFPORT_NUM = 1
-VIF_PORT = ovs_lib.VifPort('port', OFPORT_NUM,
-                           VIF_ID, VIF_MAC, 'switch')
+VIF_PORT = ovs_lib.VifPort('port', OFPORT_NUM, VIF_ID, VIF_MAC,
+                           Switch(br_name='br_name'))
 VIF_PORTS = {VIF_ID: VIF_PORT}
 FIXED_IPS = [{'subnet_id': 'my-subnet-uuid',
               'ip_address': '1.1.1.1'}]
@@ -226,8 +229,6 @@ class TunnelTest(object):
             mock.call.port_exists('int-%s' % self.MAP_TUN_BRIDGE),
             mock.call.add_patch_port('int-%s' % self.MAP_TUN_BRIDGE,
                                      constants.NONEXISTENT_PEER),
-            mock.call.set_igmp_snooping_flood('int-%s' % self.MAP_TUN_BRIDGE,
-                                              igmp_snooping),
         ]
 
         self.mock_int_bridge_expected += [
@@ -257,7 +258,6 @@ class TunnelTest(object):
         self.mock_int_bridge_expected += [
             mock.call.port_exists('patch-tun'),
             mock.call.add_patch_port('patch-tun', 'patch-int'),
-            mock.call.set_igmp_snooping_flood('patch-tun', igmp_snooping),
         ]
         self.mock_int_bridge_expected += [
             mock.call.get_vif_ports((ovs_lib.INVALID_OFPORT,
@@ -279,20 +279,6 @@ class TunnelTest(object):
         self.intb_expected = []
         self.execute_expected = []
 
-        self.mock_int_bridge_expected += [
-            mock.call.install_goto(
-                dest_table_id=constants.LOCAL_MAC_DIRECT,
-                in_port=self.MAP_TUN_INT_OFPORT,
-                priority=4, table_id=constants.TRANSIENT_TABLE),
-            mock.call.install_goto(
-                dest_table_id=constants.LOCAL_MAC_DIRECT,
-                in_port=self.TUN_OFPORT,
-                priority=4, table_id=constants.TRANSIENT_TABLE),
-            mock.call.install_goto(
-                dest_table_id=constants.TRANSIENT_EGRESS_TABLE,
-                table_id=constants.LOCAL_MAC_DIRECT),
-        ]
-
     def _build_agent(self, **config_opts_agent):
         """Configure and initialize OVS agent.
 
@@ -710,9 +696,7 @@ class TunnelTestUseVethInterco(TunnelTest):
         self.mock_int_bridge_expected += [
             mock.call.db_get_val('Interface', 'int-%s' % self.MAP_TUN_BRIDGE,
                                  'type', log_errors=False),
-            mock.call.add_port('int-%s' % self.MAP_TUN_BRIDGE),
-            mock.call.set_igmp_snooping_flood('int-%s' % self.MAP_TUN_BRIDGE,
-                                              igmp_snooping),
+            mock.call.add_port('int-%s' % self.MAP_TUN_BRIDGE)
         ]
 
         self.mock_int_bridge_expected += [
@@ -735,8 +719,7 @@ class TunnelTestUseVethInterco(TunnelTest):
         ]
         self.mock_int_bridge_expected += [
             mock.call.port_exists('patch-tun'),
-            mock.call.add_patch_port('patch-tun', 'patch-int'),
-            mock.call.set_igmp_snooping_flood('patch-tun', igmp_snooping),
+            mock.call.add_patch_port('patch-tun', 'patch-int')
         ]
         self.mock_int_bridge_expected += [
             mock.call.get_vif_ports((ovs_lib.INVALID_OFPORT,
@@ -767,20 +750,6 @@ class TunnelTestUseVethInterco(TunnelTest):
         self.execute_expected = [mock.call(['udevadm', 'settle',
                                             '--timeout=10'])]
 
-        self.mock_int_bridge_expected += [
-            mock.call.install_goto(
-                dest_table_id=constants.LOCAL_MAC_DIRECT,
-                in_port=self.MAP_TUN_INT_OFPORT,
-                priority=4, table_id=constants.TRANSIENT_TABLE),
-            mock.call.install_goto(
-                dest_table_id=constants.LOCAL_MAC_DIRECT,
-                in_port=self.TUN_OFPORT,
-                priority=4, table_id=constants.TRANSIENT_TABLE),
-            mock.call.install_goto(
-                dest_table_id=constants.TRANSIENT_EGRESS_TABLE,
-                table_id=constants.LOCAL_MAC_DIRECT),
-        ]
-
 
 class TunnelTestUseVethIntercoOSKen(TunnelTestUseVethInterco,
                                   ovs_test_base.OVSOSKenTestBase):
