@@ -13,13 +13,16 @@
 #
 import collections
 import copy
+from unittest import mock
 import uuid
 
-import mock
+from ovsdbapp.backend import ovs_idl
 
 from neutron.common.ovn import constants as ovn_const
 from neutron.common.ovn import utils
+from neutron.conf.plugins.ml2.drivers.ovn import ovn_conf
 from neutron.plugins.ml2.drivers.ovn.mech_driver.ovsdb import impl_idl_ovn
+from neutron.services.portforwarding import constants as pf_const
 from neutron.tests import base
 from neutron.tests.unit import fake_resources as fakes
 
@@ -276,7 +279,21 @@ class TestNBImplIdlOvn(TestDBImplIdlOvn):
             {'name': '$as_ip4_id_5',
              'addresses': ['20.0.2.1', '20.0.2.2'],
              'external_ids': {ovn_const.OVN_SG_EXT_ID_KEY: 'id_5'}}],
-            }
+        'lbs': [
+            {'name': 'lb_1',
+             'external_ids': {
+                 ovn_const.OVN_DEVICE_OWNER_EXT_ID_KEY:
+                     pf_const.PORT_FORWARDING_PLUGIN,
+                 ovn_const.OVN_ROUTER_NAME_EXT_ID_KEY: 'rtr_name',
+                 ovn_const.OVN_FIP_EXT_ID_KEY: 'fip_id_1'}},
+            {'name': 'lb_2',
+             'external_ids': {
+                 ovn_const.OVN_DEVICE_OWNER_EXT_ID_KEY:
+                     pf_const.PORT_FORWARDING_PLUGIN,
+                 ovn_const.OVN_ROUTER_NAME_EXT_ID_KEY: 'rtr_name',
+                 ovn_const.OVN_FIP_EXT_ID_KEY: 'fip_id_2'}},
+            {'name': 'lb_3', 'external_ids': {}}],
+    }
 
     fake_associations = {
         'lstolsp': {
@@ -326,6 +343,7 @@ class TestNBImplIdlOvn(TestDBImplIdlOvn):
         self.acl_table = fakes.FakeOvsdbTable.create_one_ovsdb_table()
         self.dhcp_table = fakes.FakeOvsdbTable.create_one_ovsdb_table()
         self.address_set_table = fakes.FakeOvsdbTable.create_one_ovsdb_table()
+        self.lb_table = fakes.FakeOvsdbTable.create_one_ovsdb_table()
 
         self._tables = {}
         self._tables['Logical_Switch'] = self.lswitch_table
@@ -336,11 +354,14 @@ class TestNBImplIdlOvn(TestDBImplIdlOvn):
         self._tables['ACL'] = self.acl_table
         self._tables['DHCP_Options'] = self.dhcp_table
         self._tables['Address_Set'] = self.address_set_table
+        self._tables['Load_Balancer'] = self.lb_table
 
-        with mock.patch.object(impl_idl_ovn.OvsdbNbOvnIdl, 'from_worker',
+        with mock.patch.object(impl_idl_ovn, 'get_connection',
                                return_value=mock.Mock()):
-            impl_idl_ovn.OvsdbNbOvnIdl.ovsdb_connection = None
-            self.nb_ovn_idl = impl_idl_ovn.OvsdbNbOvnIdl(mock.Mock())
+            with mock.patch.object(ovs_idl.Backend, 'autocreate_indices',
+                                   create=True):
+                impl_idl_ovn.OvsdbNbOvnIdl.ovsdb_connection = None
+                self.nb_ovn_idl = impl_idl_ovn.OvsdbNbOvnIdl(mock.MagicMock())
 
         self.nb_ovn_idl.idl.tables = self._tables
 
@@ -395,6 +416,28 @@ class TestNBImplIdlOvn(TestDBImplIdlOvn):
         # Load address sets
         fake_address_sets = TestNBImplIdlOvn.fake_set['address_sets']
         self._load_ovsdb_fake_rows(self.address_set_table, fake_address_sets)
+        # Load load balancers
+        fake_lbs = TestNBImplIdlOvn.fake_set['lbs']
+        self._load_ovsdb_fake_rows(self.lb_table, fake_lbs)
+
+    @mock.patch.object(ovs_idl.Backend, 'autocreate_indices', mock.Mock(),
+                       create=True)
+    @mock.patch.object(impl_idl_ovn.OvsdbNbOvnIdl, 'ovsdb_connection', None)
+    @mock.patch.object(impl_idl_ovn, 'get_connection', mock.Mock())
+    def test_setting_ovsdb_probe_timeout_default_value(self):
+        inst = impl_idl_ovn.OvsdbNbOvnIdl(mock.Mock())
+        inst.idl._session.reconnect.set_probe_interval.assert_called_with(
+            60000)
+
+    @mock.patch.object(ovs_idl.Backend, 'autocreate_indices', mock.Mock(),
+                       create=True)
+    @mock.patch.object(impl_idl_ovn.OvsdbNbOvnIdl, 'ovsdb_connection', None)
+    @mock.patch.object(impl_idl_ovn, 'get_connection', mock.Mock())
+    @mock.patch.object(ovn_conf, 'get_ovn_ovsdb_probe_interval')
+    def test_setting_ovsdb_probe_timeout(self, mock_get_probe_interval):
+        mock_get_probe_interval.return_value = 5000
+        inst = impl_idl_ovn.OvsdbNbOvnIdl(mock.Mock())
+        inst.idl._session.reconnect.set_probe_interval.assert_called_with(5000)
 
     def test_get_all_logical_switches_with_ports(self):
         # Test empty
@@ -669,10 +712,10 @@ class TestNBImplIdlOvn(TestDBImplIdlOvn):
             'ports': []}, subnet_options)
         subnet_options = self.nb_ovn_idl.get_subnet_dhcp_options(
             'subnet-id-11-0-2-0')['subnet']
-        self.assertEqual({}, subnet_options)
+        self.assertIsNone(subnet_options)
         subnet_options = self.nb_ovn_idl.get_subnet_dhcp_options(
             'port-id-30-0-1-0')['subnet']
-        self.assertEqual({}, subnet_options)
+        self.assertIsNone(subnet_options)
 
     def test_get_subnet_dhcp_options_with_ports(self):
         # Test empty
@@ -752,9 +795,90 @@ class TestNBImplIdlOvn(TestDBImplIdlOvn):
         port_group = self.nb_ovn_idl.get_port_group(str(uuid.uuid4()))
         self.assertIsNone(port_group)
 
-    def test_get_port_groups_not_supported(self):
+    def test_get_sg_port_groups_not_supported(self):
         self._load_nb_db()
         # Make sure that PG tables doesn't exist in fake db.
         self._tables.pop('Port_Group', None)
-        port_groups = self.nb_ovn_idl.get_port_groups()
+        port_groups = self.nb_ovn_idl.get_sg_port_groups()
         self.assertEqual({}, port_groups)
+
+    def test_get_router_floatingip_lbs(self):
+        lrouter_name = 'rtr_name'
+        # Empty
+        lbs = self.nb_ovn_idl.get_router_floatingip_lbs(lrouter_name)
+        self.assertEqual([], lbs)
+        self._load_nb_db()
+        lbs = self.nb_ovn_idl.get_router_floatingip_lbs('not_there')
+        self.assertEqual([], lbs)
+        lb1_row = self._find_ovsdb_fake_row(self.lb_table, 'name', 'lb_1')
+        lb2_row = self._find_ovsdb_fake_row(self.lb_table, 'name', 'lb_2')
+        lbs = self.nb_ovn_idl.get_router_floatingip_lbs(lrouter_name)
+        self.assertEqual(lbs, [lb1_row, lb2_row])
+
+    def test_get_floatingip_in_nat_or_lb(self):
+        fip_id = 'fip_id_2'
+        # Empty
+        lb = self.nb_ovn_idl.get_floatingip_in_nat_or_lb(fip_id)
+        self.assertIsNone(lb)
+        self._load_nb_db()
+        lb = self.nb_ovn_idl.get_floatingip_in_nat_or_lb('not_there')
+        self.assertIsNone(lb)
+        lb_row = self._find_ovsdb_fake_row(self.lb_table, 'name', 'lb_2')
+        lb = self.nb_ovn_idl.get_floatingip_in_nat_or_lb(fip_id)
+        self.assertEqual(lb['_uuid'], lb_row.uuid)
+
+
+class TestSBImplIdlOvn(TestDBImplIdlOvn):
+
+    fake_set = {
+        'chassis': [
+            {'name': 'host-1', 'hostname': 'host-1.localdomain.com',
+             'external_ids': {'ovn-bridge-mappings':
+                              'public:br-ex,private:br-0'}},
+            {'name': 'host-2', 'hostname': 'host-2.localdomain.com',
+             'external_ids': {'ovn-bridge-mappings':
+                              'public:br-ex,public2:br-ex'}},
+            {'name': 'host-3', 'hostname': 'host-3.localdomain.com',
+             'external_ids': {'ovn-bridge-mappings':
+                              'public:br-ex'}}],
+    }
+
+    def setUp(self):
+        super(TestSBImplIdlOvn, self).setUp()
+
+        self.chassis_table = fakes.FakeOvsdbTable.create_one_ovsdb_table()
+        self._tables = {}
+        self._tables['Chassis'] = self.chassis_table
+
+        with mock.patch.object(impl_idl_ovn, 'get_connection',
+                               return_value=mock.Mock()):
+            with mock.patch.object(ovs_idl.Backend, 'autocreate_indices',
+                                   create=True):
+                impl_idl_ovn.OvsdbSbOvnIdl.ovsdb_connection = None
+                self.sb_ovn_idl = impl_idl_ovn.OvsdbSbOvnIdl(mock.Mock())
+
+        self.sb_ovn_idl.idl.tables = self._tables
+
+    def _load_sb_db(self):
+        # Load Chassis
+        fake_chassis = TestSBImplIdlOvn.fake_set['chassis']
+        self._load_ovsdb_fake_rows(self.chassis_table, fake_chassis)
+
+    @mock.patch.object(ovs_idl.Backend, 'autocreate_indices', mock.Mock(),
+                       create=True)
+    @mock.patch.object(impl_idl_ovn.OvsdbSbOvnIdl, 'ovsdb_connection', None)
+    @mock.patch.object(impl_idl_ovn, 'get_connection', mock.Mock())
+    def test_setting_ovsdb_probe_timeout_default_value(self):
+        inst = impl_idl_ovn.OvsdbSbOvnIdl(mock.Mock())
+        inst.idl._session.reconnect.set_probe_interval.assert_called_with(
+            60000)
+
+    @mock.patch.object(ovs_idl.Backend, 'autocreate_indices', mock.Mock(),
+                       create=True)
+    @mock.patch.object(impl_idl_ovn.OvsdbSbOvnIdl, 'ovsdb_connection', None)
+    @mock.patch.object(impl_idl_ovn, 'get_connection', mock.Mock())
+    @mock.patch.object(ovn_conf, 'get_ovn_ovsdb_probe_interval')
+    def test_setting_ovsdb_probe_timeout(self, mock_get_probe_interval):
+        mock_get_probe_interval.return_value = 5000
+        inst = impl_idl_ovn.OvsdbSbOvnIdl(mock.Mock())
+        inst.idl._session.reconnect.set_probe_interval.assert_called_with(5000)
