@@ -13,7 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
 
 from futurist import periodics
 from neutron_lib import context
@@ -319,7 +319,7 @@ class TestDBInconsistenciesPeriodics(testlib_api.SqlTestCaseLight,
             attrs={'name': 'ls2',
                    'other_config': {
                         constants.MCAST_SNOOP: 'true',
-                        constants.MCAST_FLOOD_UNREGISTERED: 'false'}})
+                        constants.MCAST_FLOOD_UNREGISTERED: 'true'}})
 
         nb_idl.ls_list.return_value.execute.return_value = [ls0, ls1, ls2]
 
@@ -332,11 +332,11 @@ class TestDBInconsistenciesPeriodics(testlib_api.SqlTestCaseLight,
             mock.call('Logical_Switch', 'ls0',
                       ('other_config', {
                            constants.MCAST_SNOOP: 'true',
-                           constants.MCAST_FLOOD_UNREGISTERED: 'false'})),
+                           constants.MCAST_FLOOD_UNREGISTERED: 'true'})),
             mock.call('Logical_Switch', 'ls1',
                       ('other_config', {
                            constants.MCAST_SNOOP: 'true',
-                           constants.MCAST_FLOOD_UNREGISTERED: 'false'})),
+                           constants.MCAST_FLOOD_UNREGISTERED: 'true'})),
         ]
         nb_idl.db_set.assert_has_calls(expected_calls)
 
@@ -395,68 +395,3 @@ class TestDBInconsistenciesPeriodics(testlib_api.SqlTestCaseLight,
                       priority=constants.HA_CHASSIS_GROUP_HIGHEST_PRIORITY - 1)
         ]
         nb_idl.ha_chassis_group_add_chassis.assert_has_calls(expected_calls)
-
-    def test_check_for_mcast_flood_reports(self):
-        nb_idl = self.fake_ovn_client._nb_idl
-        lsp0 = fakes.FakeOvsdbRow.create_one_ovsdb_row(
-            attrs={'name': 'lsp0',
-                   'options': {'mcast_flood_reports': 'true'},
-                   'type': ""})
-        lsp1 = fakes.FakeOvsdbRow.create_one_ovsdb_row(
-            attrs={'name': 'lsp1', 'options': {}, 'type': ""})
-        lsp2 = fakes.FakeOvsdbRow.create_one_ovsdb_row(
-            attrs={'name': 'lsp2', 'options': {},
-                   'type': "vtep"})
-        lsp3 = fakes.FakeOvsdbRow.create_one_ovsdb_row(
-            attrs={'name': 'lsp3', 'options': {},
-                   'type': "localport"})
-        lsp4 = fakes.FakeOvsdbRow.create_one_ovsdb_row(
-            attrs={'name': 'lsp4', 'options': {},
-                   'type': "router"})
-        lsp5 = fakes.FakeOvsdbRow.create_one_ovsdb_row(
-            attrs={'name': 'lsp5', 'options': {}, 'type': 'localnet'})
-
-        nb_idl.lsp_list.return_value.execute.return_value = [
-            lsp0, lsp1, lsp2, lsp3, lsp4, lsp5]
-
-        # Invoke the periodic method, it meant to run only once at startup
-        # so NeverAgain will be raised at the end
-        self.assertRaises(periodics.NeverAgain,
-                          self.periodic.check_for_mcast_flood_reports)
-
-        # Assert only lsp1 and lsp5 were called because they are the only
-        # ones meeting the criteria ("mcast_flood_reports" not yet set,
-        # and type "" or localnet)
-        expected_calls = [
-            mock.call('lsp1', mcast_flood_reports='true'),
-            mock.call('lsp5', mcast_flood_reports='true', mcast_flood='false')]
-
-        nb_idl.lsp_set_options.assert_has_calls(expected_calls)
-
-    def test_check_router_mac_binding_options(self):
-        nb_idl = self.fake_ovn_client._nb_idl
-        lr0 = fakes.FakeOvsdbRow.create_one_ovsdb_row(
-            attrs={'name': 'lr0',
-                   'options': {'always_learn_from_arp_request': 'false',
-                               'dynamic_neigh_routers': 'true'}})
-        lr1 = fakes.FakeOvsdbRow.create_one_ovsdb_row(
-            attrs={'name': 'lr1', 'options': {}})
-        lr2 = fakes.FakeOvsdbRow.create_one_ovsdb_row(
-            attrs={'name': 'lr2', 'options': {}})
-        nb_idl.lr_list.return_value.execute.return_value = [lr0, lr1, lr2]
-
-        # Invoke the periodic method, it meant to run only once at startup
-        # so NeverAgain will be raised at the end
-        self.assertRaises(periodics.NeverAgain,
-                          self.periodic.check_router_mac_binding_options)
-
-        # Assert lr1 and lr2 had their options updated since the values
-        # were not set
-        expected_calls = [
-            mock.call('lr1',
-                      options={'always_learn_from_arp_request': 'false',
-                               'dynamic_neigh_routers': 'true'}),
-            mock.call('lr2',
-                      options={'always_learn_from_arp_request': 'false',
-                               'dynamic_neigh_routers': 'true'})]
-        nb_idl.update_lrouter.assert_has_calls(expected_calls)
