@@ -12,11 +12,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
+
+from neutron_lib import context
 from oslo_config import cfg
 import testtools
 
-from neutron import context
 from neutron.quota import resource
 from neutron.quota import resource_registry
 from neutron.tests import base
