@@ -12,7 +12,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import mock
+from unittest import mock
+
 from neutron_lib.tests.unit import fake_notifier
 from oslo_config import cfg
 from oslo_utils import fixture as utils_fixture
@@ -57,6 +58,7 @@ class TestMeteringOperations(base.BaseTestCase):
         cfg.CONF.set_override('driver', 'noop')
         cfg.CONF.set_override('measure_interval', 0)
         cfg.CONF.set_override('report_interval', 0)
+        cfg.CONF.set_override('granular_traffic_data', False)
 
         self.setup_notification_driver()
 
@@ -143,6 +145,7 @@ class TestMeteringOperations(base.BaseTestCase):
 
         cfg.CONF.set_override('measure_interval', measure_interval)
         cfg.CONF.set_override('report_interval', report_interval)
+        cfg.CONF.set_override('granular_traffic_data', False)
 
         for i in range(report_interval):
             self.agent._metering_loop()
@@ -172,9 +175,11 @@ class TestMeteringOperations(base.BaseTestCase):
     def test_router_deleted(self):
         label_id = _uuid()
         self.driver.get_traffic_counters = mock.MagicMock()
-        self.driver.get_traffic_counters.return_value = {label_id:
-                                                         {'pkts': 44,
-                                                          'bytes': 222}}
+
+        expected_traffic_counters = {'pkts': 44, 'bytes': 222}
+        self.driver.get_traffic_counters.return_value = {
+            label_id: expected_traffic_counters}
+
         self.agent._add_metering_info = mock.MagicMock()
 
         self.agent.routers_updated(None, ROUTERS)
@@ -183,7 +188,8 @@ class TestMeteringOperations(base.BaseTestCase):
         self.assertEqual(1, self.agent._add_metering_info.call_count)
         self.assertEqual(1, self.driver.remove_router.call_count)
 
-        self.agent._add_metering_info.assert_called_with(label_id, 44, 222)
+        self.agent._add_metering_info.assert_called_with(
+            label_id, expected_traffic_counters)
 
     @mock.patch('time.time')
     def _test_purge_metering_info(self, current_timestamp, is_empty,
@@ -208,16 +214,18 @@ class TestMeteringOperations(base.BaseTestCase):
     def _test_add_metering_info(self, expected_info, current_timestamp,
                                 mock_time):
         mock_time.return_value = current_timestamp
-        actual_info = self.agent._add_metering_info('fake_label_id', 1, 1)
+        actual_info = self.agent._add_metering_info(
+            'fake_label_id', expected_info)
+
         self.assertEqual(1, len(self.agent.metering_infos))
         self.assertEqual(expected_info, actual_info)
         self.assertEqual(expected_info,
                          self.agent.metering_infos['fake_label_id'])
         self.assertEqual(1, mock_time.call_count)
 
-    def test_add_metering_info_create(self):
+    def test_add_metering_info_create_no_granular_traffic_counters(self):
         expected_info = {'bytes': 1, 'pkts': 1, 'time': 0, 'first_update': 1,
-                         'last_update': 1}
+                         'last_update': 1, 'traffic-counter-granularity': None}
         self._test_add_metering_info(expected_info, 1)
 
     def test_add_metering_info_update(self):
