@@ -13,8 +13,8 @@
 #
 
 import copy
+from unittest import mock
 
-import mock
 from neutron_lib.api.definitions import external_net
 from neutron_lib.api.definitions import portbindings
 from neutron_lib.api.definitions import provider_net as pnet
@@ -23,7 +23,6 @@ from neutron_lib.callbacks import resources
 from neutron_lib import constants
 from neutron_lib import exceptions as n_exc
 from neutron_lib.exceptions import availability_zone as az_exc
-from neutron_lib.exceptions import l3 as l3_exc
 from neutron_lib.plugins import constants as plugin_constants
 from neutron_lib.plugins import directory
 from oslo_config import cfg
@@ -388,23 +387,6 @@ class TestOVNL3RouterPlugin(test_mech_driver.Ml2PluginV2TestCase):
                 ovn_const.OVN_NETWORK_NAME_EXT_ID_KEY:
                 utils.ovn_name(self.fake_network['id'])})
 
-    def test_remove_router_interface_router_not_found(self):
-        router_id = 'router-id'
-        interface_info = {'port_id': 'router-port-id'}
-        self.get_port.side_effect = n_exc.PortNotFound(
-                                        port_id='router-port-id')
-        self.get_router.side_effect = l3_exc.RouterNotFound(
-            router_id='router-id')
-
-        self.l3_inst.remove_router_interface(
-            self.context, router_id, interface_info)
-
-        self.get_router.assert_called_once_with(self.context, 'router-id')
-        self.l3_inst._ovn.lrp_del.assert_called_once_with(
-            'lrp-router-port-id', 'neutron-router-id', if_exists=True)
-        self.del_rev_p.assert_called_once_with(
-            self.context, 'router-port-id', ovn_const.TYPE_ROUTER_PORTS)
-
     @mock.patch('neutron.db.extraroute_db.ExtraRoute_dbonly_mixin.'
                 'update_router')
     @mock.patch('neutron.plugins.ml2.drivers.ovn.mech_driver.ovsdb'
@@ -538,8 +520,7 @@ class TestOVNL3RouterPlugin(test_mech_driver.Ml2PluginV2TestCase):
                         ovn_const.OVN_ROUTER_AZ_HINTS_EXT_ID_KEY: ''}
         self.l3_inst._ovn.create_lrouter.assert_called_once_with(
             'neutron-router-id', external_ids=external_ids,
-            enabled=True, options={'always_learn_from_arp_request': 'false',
-                                   'dynamic_neigh_routers': 'true'})
+            enabled=True, options={})
         self.l3_inst._ovn.add_lrouter_port.assert_called_once_with(
             **self.fake_ext_gw_port_assert)
         expected_calls = [
@@ -890,6 +871,8 @@ class TestOVNL3RouterPlugin(test_mech_driver.Ml2PluginV2TestCase):
                 'ovn_client.OVNClient._check_external_ips_changed')
     @mock.patch.object(utils, 'get_lrouter_snats')
     @mock.patch.object(utils, 'get_lrouter_ext_gw_static_route')
+    @mock.patch('neutron.common.ovn.utils.is_snat_enabled',
+                mock.Mock(return_value=True))
     @mock.patch('neutron.plugins.ml2.drivers.ovn.mech_driver.ovsdb.'
                 'ovn_client.OVNClient._get_router_ports')
     @mock.patch('neutron.db.extraroute_db.ExtraRoute_dbonly_mixin.'
@@ -936,8 +919,6 @@ class TestOVNL3RouterPlugin(test_mech_driver.Ml2PluginV2TestCase):
             external_ip='192.168.0.10',
             logical_port='port_id',
             external_ids=expected_ext_ids)
-        self.l3_inst._ovn.delete_lswitch_port.assert_called_once_with(
-            'fip-port-id', 'neutron-fip-net-id')
 
     def test_create_floatingip_distributed(self):
         self.l3_inst._ovn.is_col_present.return_value = True
@@ -1009,8 +990,6 @@ class TestOVNL3RouterPlugin(test_mech_driver.Ml2PluginV2TestCase):
             external_ip='192.168.0.10',
             logical_port='port_id',
             external_ids=expected_ext_ids)
-        self.l3_inst._ovn.delete_lswitch_port.assert_called_once_with(
-            'fip-port-id', 'neutron-fip-net-id')
 
     def test_create_floatingip_external_ip_present_type_snat(self):
         self.l3_inst._ovn.is_col_present.return_value = True
@@ -1035,8 +1014,6 @@ class TestOVNL3RouterPlugin(test_mech_driver.Ml2PluginV2TestCase):
             external_ip='192.168.0.10',
             logical_port='port_id',
             external_ids=expected_ext_ids)
-        self.l3_inst._ovn.delete_lswitch_port.assert_called_once_with(
-            'fip-port-id', 'neutron-fip-net-id')
 
     def test_create_floatingip_lsp_external_id(self):
         foo_lport = fake_resources.FakeOvsdbRow.create_one_ovsdb_row()
@@ -1432,7 +1409,7 @@ class TestOVNL3RouterPlugin(test_mech_driver.Ml2PluginV2TestCase):
         self.nb_idl().get_gateway_chassis_binding.side_effect = (
             existing_port_bindings)
         # for 1. port schedule untouched, add only 3'rd chassis
-        # for 2. port master scheduler somewhere else
+        # for 2. port primary scheduler somewhere else
         # for 3. port schedule all
         self.mock_schedule.side_effect = [
             ['chassis1', 'chassis2', 'chassis3'],
@@ -1452,7 +1429,7 @@ class TestOVNL3RouterPlugin(test_mech_driver.Ml2PluginV2TestCase):
                       'lrp-foo-2', [], ['chassis2']),
             mock.call(self.nb_idl(), self.sb_idl(),
                       'lrp-foo-3', [], [])])
-        # make sure that for second port master chassis stays untouched
+        # make sure that for second port primary chassis stays untouched
         self.nb_idl().update_lrouter_port.assert_has_calls([
             mock.call('lrp-foo-1',
                       gateway_chassis=['chassis1', 'chassis2', 'chassis3']),
