@@ -29,9 +29,6 @@ LANG=C
 # overcloud deploy script for OVN migration.
 : ${OVERCLOUD_OVN_DEPLOY_SCRIPT:=~/overcloud-deploy-ovn.sh}
 
-# user on the nodes in the undercloud
-: ${UNDERCLOUD_NODE_USER:=heat-admin}
-
 : ${OPT_WORKDIR:=$PWD}
 : ${STACK_NAME:=overcloud}
 : ${PUBLIC_NETWORK_NAME:=public}
@@ -113,7 +110,6 @@ gathering = smart
 fact_caching = jsonfile
 fact_caching_connection = ./ansible_facts_cache
 fact_caching_timeout = 0
-log_path = $HOME/ovn_migration_ansible.log
 
 #roles_path = roles:...
 
@@ -127,8 +123,6 @@ EOF
 
 # Generate the inventory file for ansible migration playbook.
 generate_ansible_inventory_file() {
-    local dhcp_nodes
-
     echo "Generating the inventory file for ansible-playbook"
     source $STACKRC_FILE
     echo "[ovn-dbs]"  > hosts_for_migration
@@ -144,7 +138,7 @@ generate_ansible_inventory_file() {
             ovn_central=False
             node="$node_name ansible_host=$node_ip ovn_central=true"
         fi
-        echo $node ansible_ssh_user=$UNDERCLOUD_NODE_USER ansible_become=true >> hosts_for_migration
+        echo $node ansible_ssh_user=heat-admin ansible_become=true >> hosts_for_migration
     done
 
     echo "" >> hosts_for_migration
@@ -154,24 +148,15 @@ generate_ansible_inventory_file() {
     OVN_CONTROLLERS=$(get_group_hosts "$inventory_file" neutron_ovs_agent)
     for node_name in $OVN_CONTROLLERS; do
         node_ip=$(get_host_ip "$inventory_file" $node_name)
-        echo $node_name ansible_host=$node_ip ansible_ssh_user=$UNDERCLOUD_NODE_USER ansible_become=true ovn_controller=true >> hosts_for_migration
+        echo $node_name ansible_host=$node_ip ansible_ssh_user=heat-admin ansible_become=true ovn_controller=true >> hosts_for_migration
     done
-
-    echo "" >> hosts_for_migration
-    echo "[dhcp]" >> hosts_for_migration
-    dhcp_nodes=$(get_group_hosts "$inventory_file" neutron_dhcp)
-    for node_name in $dhcp_nodes; do
-        node_ip=$(get_host_ip "$inventory_file" $node_name)
-        echo $node_name ansible_host=$node_ip ansible_ssh_user=$UNDERCLOUD_NODE_USER ansible_become=true >> hosts_for_migration
-    done
-
     rm -f "$inventory_file"
     echo "" >> hosts_for_migration
 
     cat >> hosts_for_migration << EOF
 
 [overcloud-controllers:children]
-dhcp
+ovn-dbs
 
 [overcloud:children]
 ovn-controllers
@@ -183,7 +168,7 @@ EOF
     cat >> hosts_for_migration << EOF
 
 [$1:vars]
-remote_user=$UNDERCLOUD_NODE_USER
+remote_user=heat-admin
 public_network_name=$PUBLIC_NETWORK_NAME
 image_name=$IMAGE_NAME
 working_dir=$OPT_WORKDIR
@@ -220,7 +205,6 @@ function check_stack {
 
 oc_check_public_network() {
 
-    [ "$VALIDATE_MIGRATION" != "True" ] && return 0
     source $OVERCLOUDRC_FILE
     openstack network show $PUBLIC_NETWORK_NAME 1>/dev/null || {
         echo "ERROR: PUBLIC_NETWORK_NAME=${PUBLIC_NETWORK_NAME} can't be accessed by the"
